@@ -20,7 +20,9 @@ def main( argv ):
             key, value = [s.strip() for s in line.split('=',1)]
             branding_info[ key ] = value
 
-    build_revision = os.popen( 'svnversion -c "%s" 2>&1' % os.environ.get( 'PYSVN_EXPORTED_FROM', '..' ), 'r' ).read().strip()
+    wc_svnversion = os.environ[ 'WC_SVNVERSION' ]
+    exported_from = os.environ.get( 'PYSVN_EXPORTED_FROM', '..' )
+    build_revision = os.popen( '%s -c "%s" 2>&1' % (wc_svnversion, exported_from), 'r' ).read().strip()
     # build_revision is either a range nnn:mmm or mmm
     # we only want the mmm
     build_revision = build_revision.split(':')[-1]
