@@ -5,11 +5,12 @@ import bundlebuilder
 import sys
 import pysvn
 import shutil
+import glob
 
 # make sure that we get 2.6 and not an earlier version
 if not hasattr(sys, 'frozen'):
     import wxversion
-    wxversion.select('2.6')
+    wxversion.select( ['2.6', '2.8'] )
 
 import wx
 import os
@@ -56,10 +57,11 @@ try:
     #myapp.includePackages.append("Menu")
 
     # Here you add supporting files and/or folders to your bundle
-    #myapp.resources.append(os.path.join(packageroot,"icons" ))
+    for locale_lang_root in glob.glob( '../../Source/locale/??' ):
+        myapp.resources.append( os.path.join( locale_lang_root, 'LC_MESSAGES/pysvn_workbench.mo' ) )
 
-    # bundlebuilder does not yet have the capability to detect what shared  libraries
-    # are needed by your app - so in this case I am adding the wxPython  libs manually
+    # bundlebuilder does not yet have the capability to detect what shared libraries
+    # are needed by your app - so in this case I am adding the wxPython libs manually
 
     wx_ver = '%d.%d.%d.%d%s' % wx.VERSION
     wx_3ver = '%d.%d.%d' % wx.VERSION[0:3]
