@@ -17,6 +17,7 @@ import logging
 import tempfile
 import threading
 import inspect
+import gettext
 
 import wx
 import wx.lib
@@ -32,7 +33,15 @@ import wb_dialogs
 import wb_background_thread
 import wb_shell_commands
 
-wx.InitAllImageHandlers()
+# 2.8 has the convenient ACCEL_CMD
+# on 2.6 we can add the feature
+try: 
+    wx.ACCEL_CMD
+except AttributeError:
+    if 'wxMac' in wx.PlatformInfo:
+        wx.ACCEL_CMD = wx.ACCEL_ALT
+    else:
+        wx.ACCEL_CMD = wx.ACCEL_CTRL
 
 AppCallBackEvent, EVT_APP_CALLBACK = wx.lib.newevent.NewEvent()
 
@@ -41,6 +50,9 @@ class WbApp(wx.App):
         self.args = args
         self.app_name = os.path.basename( args[0] )
         self.app_dir = os.path.dirname( args[0] )
+        if self.app_dir == '':
+            self.app_dir = startup_dir
+
         self.main_thread = threading.currentThread()
 
         self.progress_format = None
@@ -48,6 +60,19 @@ class WbApp(wx.App):
 
         wb_platform_specific.setupPlatform()
 
+        locale_path = wb_platform_specific.getLocalePath( self )
+        self.translation = gettext.translation(
+                'pysvn_workbench',
+                locale_path,
+                # language defaults 
+                fallback=True )
+
+        import __builtin__
+        __builtin__.__dict__['T_'] = self.translation.ugettext
+        __builtin__.__dict__['S_'] = self.translation.ungettext
+        __builtin__.__dict__['U_'] = lambda s: s
+
+
         # --project <dir> automatically creates a project entry for <dir>
         # if <dir> is a subversion working copy and no project entry exists for it.
         self.auto_project_dir = None
@@ -69,6 +94,12 @@ class WbApp(wx.App):
 
         self.setupLogging()
 
+        self.log.info( 'app_name %s app_dir %s' % (self.app_name, self.app_dir) )
+        self.log.info( 'locale_path %s' % locale_path )
+        self.log.info( 'find %r' % gettext.find( 'pysvn_workbench', locale_path ) )
+        self.log.info( 'info %r' % self.translation.info() )
+        self.log.info( T_('PySVN WorkBench') )
+
         if '--test' in args:
             self.prefs = wb_preferences.Preferences(
                     self,
@@ -141,7 +172,7 @@ class WbApp(wx.App):
             handler.setFormatter( formatter )
             self.trace.addHandler( handler )
 
-        self.log.info( 'Work Bench starting' )
+        self.log.info( T_('Work Bench starting') )
 
         self.log.debug( 'debug enabled' )
         self.trace.info( 'trace enabled' )
