@@ -46,13 +46,13 @@ class DialogBuildingBlock(wx.Dialog):
         self.log_message_ctrl = None
         if self.add_log_message_field:
             self.log_message_ctrl = wx.TextCtrl( self, id_log_message_text, size=wx.Size( 600, 200 ), style=wx.TE_MULTILINE )
+            self.log_message_ctrl.SetFocus()
 
         self.force_checkbox_ctrl = None
         if self.add_force_field:
             self.force_checkbox_ctrl = wx.CheckBox( self, -1, "Force" )
             self.force_checkbox_ctrl.SetValue( False )
 
-
         self.button_ok = wx.Button( self, wx.ID_OK, " OK " )
         self.button_cancel = wx.Button( self, wx.ID_CANCEL, " Cancel " )
         self.button_ok.SetDefault()
@@ -164,6 +164,8 @@ class GetCredentials(wx.Dialog):
 
         self.username_label = wx.StaticText( self, -1, 'Username:' )
         self.username_ctrl = wx.TextCtrl( self, -1, username )
+        self.username_ctrl.SetFocus()
+        self.username_ctrl.SetSelection( -1, -1 )
 
         self.g_sizer.Add( self.username_label, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 3 )
         self.g_sizer.Add( self.username_ctrl, 0, wx.EXPAND|wx.EAST, 5 )
@@ -350,6 +352,8 @@ class RenameFile(wx.Dialog):
 
         self.new_filename_text = wx.StaticText( self, -1, 'To:' )
         self.new_filename_ctrl = wx.TextCtrl( self, -1, old_filename )
+        self.new_filename_ctrl.SetSelection( -1, -1 )
+        self.new_filename_ctrl.SetFocus()
 
         self.g_sizer.Add( self.new_filename_text, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 3 )
         self.g_sizer.Add( self.new_filename_ctrl, 0, wx.EXPAND|wx.EAST, 5 )
@@ -412,6 +416,8 @@ class GetFilename(wx.Dialog):
 
         self.new_filename_text = wx.StaticText( self, -1, 'Name:' )
         self.new_filename_ctrl = wx.TextCtrl( self, -1, 'New Folder' )
+        self.new_filename_ctrl.SetSelection( -1, -1 )
+        self.new_filename_ctrl.SetFocus()
 
         self.g_sizer.Add( self.new_filename_text, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 3 )
         self.g_sizer.Add( self.new_filename_ctrl, 0, wx.EXPAND|wx.EAST, 5 )
@@ -454,8 +460,6 @@ class NewFile(wx.Dialog):
     def __init__( self, parent, template_dir ):
         wx.Dialog.__init__( self, parent, -1, 'New File' )
 
-
-
         self.g_sizer = wx.FlexGridSizer( 0, 2, 0, 0 )
         self.g_sizer.AddGrowableCol( 1 )
 
@@ -465,6 +469,8 @@ class NewFile(wx.Dialog):
 
         self.newfile_text = wx.StaticText( self, -1, 'New Filename:' )
         self.newfile_ctrl = wx.TextCtrl( self, -1, '' )
+        self.newfile_ctrl.SetFocus()
+        self.newfile_ctrl.SetSelection( -1, -1 )
 
         self.g_sizer.Add( self.newfile_text, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 5 )
         self.g_sizer.Add( self.newfile_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
@@ -517,7 +523,6 @@ class NewFile(wx.Dialog):
 
     def getTemplateFilename( self ):
         index = self.template_list.GetCurrentSelection()
-        print 'getTemplateFilename',len(self.template_file_list),index
         if index >= 0 and len(self.template_file_list) > index:
             return self.template_file_list[ index ] + self.template_suffix
         else:
@@ -540,6 +545,7 @@ class CopyUrl(wx.Dialog):
         self.copy_to_label = wx.StaticText( self, -1, 'Copy To:' )
         self.copy_to_root = wx.StaticText( self, -1, copy_to_url + '/' )
         self.copy_to_leaf = wx.TextCtrl( self, -1, '' )
+        self.copy_to_leaf.SetFocus()
 
         self.h_sizer_copy_to = wx.BoxSizer( wx.HORIZONTAL )
         self.h_sizer_copy_to.Add( self.copy_to_root, 0, wx.EXPAND|wx.EAST, 15 )
