@@ -114,6 +114,7 @@ class DiffFrame(wx.Frame):
             return
 
         self.setChangeCounts( None, self.processor.getChangeCount() )
+        self.SetZoom(diff_prefs.zoom)
 
         # Move to the first change in the editor.
         event = wx.CommandEvent( wx.wxEVT_COMMAND_TOOL_CLICKED, id_next_command )
@@ -143,6 +144,9 @@ class DiffFrame(wx.Frame):
         wx.EVT_SIZE( self, self.OnFrameSize )
         wx.EVT_MOVE( self, self.OnFrameMove )
 
+        wx.stc.EVT_STC_ZOOM(self, self.panel_left.ed.GetId(), self.OnZoomChange)
+        wx.stc.EVT_STC_ZOOM(self, self.panel_right.ed.GetId(), self.OnZoomChange)
+
 
     def isOk( self ):
         return self.files_ok
@@ -232,7 +236,20 @@ class DiffFrame(wx.Frame):
         self.panel_left.ed.ShowAllFolds( show )
         self.panel_right.ed.ShowAllFolds( show )
 
-
+    def OnZoomChange(self, evt):
+        zoom = evt.GetEventObject().GetZoom()
+        self.SetZoom(zoom)
+        diff_prefs = self.app.prefs.getDiffWindow()
+        diff_prefs.zoom = zoom
+        
+    def SetZoom(self, zoom):
+        if zoom != self.panel_left.ed.GetZoom():
+            self.panel_left.ed.SetZoom(zoom)
+        if zoom != self.panel_right.ed.GetZoom():
+            self.panel_right.ed.SetZoom(zoom)
+        self.panel_left.ed.diff_line_numbers.SetZoom(zoom)
+        self.panel_right.ed.diff_line_numbers.SetZoom(zoom)
+            
 #----------------------------------------------------------------------
 
 WB_EVT_SYNC_SCROLL_type = wx.NewEventType()
