@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2007 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -17,14 +17,15 @@ VERSION_STRING = "Uncontrolled"
 import sys
 
 # make sure that we get 2.6 and not an earlier version
+# 2.8 is reported to work as well
 if not hasattr(sys, 'frozen'):
     import wxversion
-    wxversion.select('2.6')
+    wxversion.select( ['2.6', '2.8'] )
 
 import wx
 import wb_diff_frame
 import wb_preferences
-
+import wb_platform_specific
 
 class WbDiffApp:
     def __init__( self ):
