@@ -35,106 +35,113 @@ class WbFrame(wx.Frame):
     status_progress = 1
     status_action = 2
     status_num_fields = 3
-    status_widths = [-1, 100, -2]
+    status_widths = [-1, 150, -2]
 
     def __init__( self, app ):
         self.app = app
-        title = 'Work Bench'
+        title = T_('PySVN WorkBench')
 
         win_prefs = self.app.prefs.getWindow()
 
         extra_style = 0
         if win_prefs.maximized:
             extra_style = wx.MAXIMIZE
+
         wx.Frame.__init__(self, None, -1, title,
                 win_prefs.frame_position,
                 win_prefs.frame_size,
                 wx.DEFAULT_FRAME_STYLE|extra_style )
 
+        # Reset the size after startup to workaround a potential
+        # problem on OSX with incorrect first size event saving the
+        # wrong size in teh preferences
+        wx.CallAfter(self.SetSize, win_prefs.frame_size)
+        
         self.menu_edit = wx.Menu()
-        self.menu_edit.Append( wb_ids.id_SP_EditCopy, "&Copy", "Copy Files" )
-        self.menu_edit.Append( wb_ids.id_SP_EditCut, "&Cut", "Cut Files" )
-        self.menu_edit.Append( wb_ids.id_SP_EditPaste, "&Paste", "Paste Files" )
+        self.menu_edit.Append( wb_ids.id_SP_EditCopy, T_("&Copy"), T_("Copy Files") )
+        self.menu_edit.Append( wb_ids.id_SP_EditCut, T_("&Cut"), T_("Cut Files") )
+        self.menu_edit.Append( wb_ids.id_SP_EditPaste, T_("&Paste"), T_("Paste Files") )
         self.menu_edit.AppendSeparator()
-        self.menu_edit.Append( wb_ids.id_ClearLog, "&Clear log", "Clear the log window" )
+        self.menu_edit.Append( wb_ids.id_ClearLog, T_("&Clear log"), T_("Clear the log window") )
 
         if wx.Platform != '__WXMAC__':
             self.menu_file = wx.Menu()
         else:
             self.menu_file = self.menu_edit
 
-        self.menu_file.Append( wx.ID_PREFERENCES, "&Preferences...", "Preferences" )
-        self.menu_file.Append( wx.ID_EXIT, "E&xit", "Exit the application" )
+        self.menu_file.Append( wx.ID_PREFERENCES, T_("&Preferences..."), T_("Preferences") )
+        self.menu_file.Append( wx.ID_EXIT, T_("E&xit"), T_("Exit the application") )
 
         self.menu_actions = wx.Menu()
-        self.menu_actions.Append(  wb_ids.id_Command_Shell, '&Command Shell', 'Command Shell' )
-        self.menu_actions.Append(  wb_ids.id_File_Browser, '&File Browser', 'File Browser' )
+        self.menu_actions.Append(  wb_ids.id_Command_Shell, T_('&Command Shell'), T_('Command Shell') )
+        self.menu_actions.Append(  wb_ids.id_File_Browser, T_('&File Browser'), T_('File Browser') )
         self.menu_actions.AppendSeparator()
-        self.menu_actions.Append(  wb_ids.id_File_Edit, 'Edit', 'Edit' )
-        self.menu_actions.Append(  wb_ids.id_Shell_Open, 'Open', 'Open' )
+        self.menu_actions.Append(  wb_ids.id_File_Edit, T_('Edit'), T_('Edit') )
+        self.menu_actions.Append(  wb_ids.id_Shell_Open, T_('Open'), T_('Open') )
         self.menu_actions.AppendSeparator()
-        self.menu_actions.Append(  wb_ids.id_SP_DiffWorkBase, 'Diff WC vs. BASE...', 'Diff WC vs. BASE...' )
-        self.menu_actions.Append(  wb_ids.id_SP_DiffWorkHead, 'Diff WC vs. HEAD...', 'Diff WC vs. HEAD...' )
-        self.menu_actions.Append(  wb_ids.id_SP_DiffWorkBranchOriginBase, 'Diff WC vs. branch origin BASE...', 'Diff WC vs. branch origin BASE...' )
-        self.menu_actions.Append(  wb_ids.id_SP_DiffWorkBranchOriginHead, 'Diff WC vs. branch origin HEAD...', 'Diff WC vs. branch origin HEAD...' )
+        self.menu_actions.Append(  wb_ids.id_SP_DiffWorkBase, T_('Diff WC vs. BASE...'), T_('Diff WC vs. BASE...') )
+        self.menu_actions.Append(  wb_ids.id_SP_DiffWorkHead, T_('Diff WC vs. HEAD...'), T_('Diff WC vs. HEAD...') )
+        self.menu_actions.Append(  wb_ids.id_SP_DiffWorkBranchOriginBase, T_('Diff WC vs. branch origin BASE...'), T_('Diff WC vs. branch origin BASE...') )
+        self.menu_actions.Append(  wb_ids.id_SP_DiffWorkBranchOriginHead, T_('Diff WC vs. branch origin HEAD...'), T_('Diff WC vs. branch origin HEAD...') )
 
         self.menu_actions_conflict = wx.Menu()
-        self.menu_actions.AppendMenu( wb_ids.id_SP_ConflictMenu, 'Conflict', self.menu_actions_conflict )
-        self.menu_actions_conflict.Append( wb_ids.id_SP_DiffOldMine, 'Diff Conflict Old vs. Mine...', 'Diff Conflict Old vs. Mine...' )
-        self.menu_actions_conflict.Append( wb_ids.id_SP_DiffMineNew, 'Diff Conflict Mine vs. New...', 'Diff Conflict Mine vs. New...' )
-        self.menu_actions_conflict.Append( wb_ids.id_SP_DiffOldNew, 'Diff Conflict Old vs. New...', 'Diff Conflict Old vs. New...' )
+        self.menu_actions.AppendMenu( wb_ids.id_SP_ConflictMenu, T_('Conflict'), self.menu_actions_conflict )
+        self.menu_actions_conflict.Append( wb_ids.id_SP_DiffOldMine, T_('Diff Conflict Old vs. Mine...'), T_('Diff Conflict Old vs. Mine...') )
+        self.menu_actions_conflict.Append( wb_ids.id_SP_DiffMineNew, T_('Diff Conflict Mine vs. New...'), T_('Diff Conflict Mine vs. New...') )
+        self.menu_actions_conflict.Append( wb_ids.id_SP_DiffOldNew, T_('Diff Conflict Old vs. New...'), T_('Diff Conflict Old vs. New...') )
         self.menu_actions_conflict.AppendSeparator()
-        self.menu_actions_conflict.Append( wb_ids.id_SP_Resolved, 'Resolved Conflict', 'Resolved Conflict' )
+        self.menu_actions_conflict.Append( wb_ids.id_SP_Resolved, T_('Resolved Conflict'), T_('Resolved Conflict') )
 
         self.menu_actions.AppendSeparator()
-        self.menu_actions.Append( wb_ids.id_SP_Annotate, 'Annotate...', 'Annotate...' )
-        self.menu_actions.Append( wb_ids.id_SP_History, 'Log history...', 'Log history...' )
-        self.menu_actions.Append( wb_ids.id_SP_Info, 'Information...', 'Information...' )
-        self.menu_actions.Append( wb_ids.id_SP_Properties, 'Properties...', 'Properties...' )
+        self.menu_actions.Append( wb_ids.id_SP_Annotate, T_('Annotate...'), T_('Annotate...') )
+        self.menu_actions.Append( wb_ids.id_SP_History, T_('Log history...'), T_('Log history...') )
+        self.menu_actions.Append( wb_ids.id_SP_Info, T_('Information...'), T_('Information...') )
+        self.menu_actions.Append( wb_ids.id_SP_Properties, T_('Properties...'), T_('Properties...') )
         self.menu_actions.AppendSeparator()
-        self.menu_actions.Append( wb_ids.id_SP_Update, 'Update', 'Update' )
-        self.menu_actions.Append( wb_ids.id_SP_Checkout, 'Checkout', 'Checkout' )
+        self.menu_actions.Append( wb_ids.id_SP_Update, T_('Update'), T_('Update') )
+        self.menu_actions.Append( wb_ids.id_SP_Checkout, T_('Checkout'), T_('Checkout') )
         self.menu_actions.AppendSeparator()
-        self.menu_actions.Append( wb_ids.id_SP_Checkin, 'Checkin...', 'Checkin...' )
+        self.menu_actions.Append( wb_ids.id_SP_Checkin, T_('Checkin...'), T_('Checkin...') )
         self.menu_actions.AppendSeparator()
-        self.menu_actions.Append( wb_ids.id_SP_Lock, 'Lock...', 'Lock...' )
-        self.menu_actions.Append( wb_ids.id_SP_Unlock, 'Unlock...', 'Unlock...' )
+        self.menu_actions.Append( wb_ids.id_SP_Lock, T_('Lock...'), T_('Lock...') )
+        self.menu_actions.Append( wb_ids.id_SP_Unlock, T_('Unlock...'), T_('Unlock...') )
         self.menu_actions.AppendSeparator()
-        self.menu_actions.Append( wb_ids.id_SP_NewFile, 'New File...', 'New File...' )
-        self.menu_actions.Append( wb_ids.id_SP_Mkdir, 'Make directory...', 'Make directory...' )
-        self.menu_actions.Append( wb_ids.id_SP_Add, 'Add', 'Add' )
-        self.menu_actions.Append( wb_ids.id_SP_Rename, 'Rename...', 'Rename' )
+        self.menu_actions.Append( wb_ids.id_SP_NewFile, T_('New File...'), T_('New File...') )
+        self.menu_actions.Append( wb_ids.id_SP_Mkdir, T_('Make directory...'), T_('Make directory...') )
+        self.menu_actions.Append( wb_ids.id_SP_Add, T_('Add'), T_('Add') )
+        self.menu_actions.Append( wb_ids.id_SP_Rename, T_('Rename...'), T_('Rename') )
         self.menu_actions.AppendSeparator()
-        self.menu_actions.Append( wb_ids.id_SP_Delete, 'Delete...', 'Delete' )
-        self.menu_actions.Append( wb_ids.id_SP_Revert, 'Revert...', 'Revert' )
+        self.menu_actions.Append( wb_ids.id_SP_Delete, T_('Delete...'), T_('Delete') )
+        self.menu_actions.Append( wb_ids.id_SP_Revert, T_('Revert...'), T_('Revert') )
         self.menu_actions.AppendSeparator()
-        self.menu_actions.Append( wb_ids.id_SP_Cleanup, 'Clean up', 'Clean up working copy' )
+        self.menu_actions.Append( wb_ids.id_SP_Cleanup, T_('Clean up'), T_('Clean up working copy') )
         self.menu_actions.AppendSeparator()
-        self.menu_actions.Append( wb_ids.id_SP_CreateTag, 'Create Tag...', 'Create Tag' )
-        self.menu_actions.Append( wb_ids.id_SP_CreateBranch, 'Create Branch...', 'Create Branch' )
+        self.menu_actions.Append( wb_ids.id_SP_CreateTag, T_('Create Tag...'), T_('Create Tag') )
+        self.menu_actions.Append( wb_ids.id_SP_CreateBranch, T_('Create Branch...'), T_('Create Branch') )
 
         self.menu_reports = wx.Menu()
-        self.menu_reports.Append( wb_ids.id_SP_Report_LocksWc, 'Working copy Locks...', 'Locks held in Working Copy' )
-        self.menu_reports.Append( wb_ids.id_SP_Report_LocksRepos, 'Repository Locks...', 'Locks held in Repository' )
+        self.menu_reports.Append( wb_ids.id_SP_Report_LocksWc, T_('Working copy Locks...'), T_('Locks held in Working Copy') )
+        self.menu_reports.Append( wb_ids.id_SP_Report_LocksRepos, T_('Repository Locks...'), T_('Locks held in Repository') )
         self.menu_reports.AppendSeparator()
-        self.menu_reports.Append( wb_ids.id_SP_Checkin, 'Changes...', 'Changes available for checkin' )
-        self.menu_reports.Append( wb_ids.id_SP_Report_Updates, 'Updates...', 'Updates available in the Repository' )
-        self.menu_reports.Append( wb_ids.id_SP_Report_BranchChanges, 'Branch changes...', 'Files changed in this branch' )
+        self.menu_reports.Append( wb_ids.id_SP_Checkin, T_('Changes...'), T_('Changes available for checkin') )
+        self.menu_reports.Append( wb_ids.id_SP_Report_Updates, T_('Updates...'), T_('Updates available in the Repository') )
+        self.menu_reports.Append( wb_ids.id_SP_Report_BranchChanges, T_('Branch changes...'), T_('Files changed in this branch') )
 
         self.menu_view = wx.Menu()
-        self.menu_view.AppendCheckItem( wb_ids.id_View_ControlledFiles, "Show &Controlled files", "Show Controlled files" )
-        self.menu_view.AppendCheckItem( wb_ids.id_View_UncontrolledFiles, "Show &Uncontrolled files", "Show Uncontrolled files" )
-        self.menu_view.AppendCheckItem( wb_ids.id_View_IgnoredFiles, "Show &Ignored files", "Show ignored files" )
+        self.menu_view.AppendCheckItem( wb_ids.id_View_ControlledFiles, T_("Show &Controlled files"), T_("Show Controlled files") )
+        self.menu_view.AppendCheckItem( wb_ids.id_View_UncontrolledFiles, T_("Show &Uncontrolled files"), T_("Show Uncontrolled files") )
+        self.menu_view.AppendCheckItem( wb_ids.id_View_IgnoredFiles, T_("Show &Ignored files"), T_("Show ignored files") )
+        self.menu_view.AppendCheckItem( wb_ids.id_View_OnlyChanges, T_("Show &Only changed files"), T_("Filter out unchanged files") )
         self.menu_view.AppendSeparator()
-        self.menu_view.AppendCheckItem( wb_ids.id_View_Diff_WbDiff, 'Use WorkBench Diff' )
-        self.menu_view.AppendCheckItem( wb_ids.id_View_Diff_ExtGuiDiff, 'Use External GUI Diff' )
-        self.menu_view.AppendCheckItem( wb_ids.id_View_Diff_ExtTextDiff, 'Use External Text Diff' )
-        self.menu_view.AppendCheckItem( wb_ids.id_View_Diff_SvnDiff, 'Use SVN Diff' )
+        self.menu_view.AppendCheckItem( wb_ids.id_View_Recursive, T_("Show &Recursive files"), T_("Show recursive files") )
         self.menu_view.AppendSeparator()
-        self.menu_view.AppendCheckItem( wb_ids.id_View_Recursive, "Show &Recursive files", "Show recursive files" )
+        self.menu_view.AppendCheckItem( wb_ids.id_View_Diff_WbDiff, T_('Use WorkBench Diff') )
+        self.menu_view.AppendCheckItem( wb_ids.id_View_Diff_ExtGuiDiff, T_('Use External GUI Diff') )
+        self.menu_view.AppendCheckItem( wb_ids.id_View_Diff_ExtTextDiff, T_('Use External Text Diff') )
+        self.menu_view.AppendCheckItem( wb_ids.id_View_Diff_SvnDiff, T_('Use SVN Diff') )
         self.menu_view.AppendSeparator()
-        self.menu_view.Append( wb_ids.id_View_Refresh, "&Refresh\tF5", "Refresh display" )
-        self.menu_view.AppendCheckItem( wb_ids.id_View_AutoRefresh, "&Automatic Refresh", "Automatic refresh" )
+        self.menu_view.Append( wb_ids.id_View_Refresh, T_("&Refresh\tF5"), T_("Refresh display") )
+        self.menu_view.AppendCheckItem( wb_ids.id_View_AutoRefresh, T_("&Automatic Refresh"), T_("Automatic refresh") )
 
 
 
@@ -143,31 +150,31 @@ class WbFrame(wx.Frame):
         self.all_bookmark_folders = {}
 
         self.menu_bookmarks = wx.Menu()
-        self.menu_bookmarks.Append( wb_ids.id_Bookmark_Add, 'Add', 'Add Bookmark' )
-        self.menu_bookmarks.Append( wb_ids.id_Bookmark_Manage, 'Manage...', 'Manage Bookmarks' )
+        self.menu_bookmarks.Append( wb_ids.id_Bookmark_Add, T_('Add'), T_('Add Bookmark') )
+        self.menu_bookmarks.Append( wb_ids.id_Bookmark_Manage, T_('Manage...'), T_('Manage Bookmarks') )
         self.menu_bookmarks.AppendSeparator()
 
         self.__bookmarkMenuReorder()
 
         self.menu_project = wx.Menu()
-        self.menu_project.Append( wb_ids.id_Project_Add, 'Add...', 'Project Add' )
-        self.menu_project.Append( wb_ids.id_Project_Update, 'Update...', 'Update Project' )
+        self.menu_project.Append( wb_ids.id_Project_Add, T_('Add...'), T_('Project Add') )
+        self.menu_project.Append( wb_ids.id_Project_Update, T_('Update...'), T_('Update Project') )
         self.menu_project.AppendSeparator()
-        self.menu_project.Append( wb_ids.id_Project_Delete, 'Delete...', 'Delete Project' )
+        self.menu_project.Append( wb_ids.id_Project_Delete, T_('Delete...'), T_('Delete Project') )
 
         self.menu_help = wx.Menu()
-        self.menu_help.Append( wx.ID_ABOUT, "&About...", "About the application" )
+        self.menu_help.Append( wx.ID_ABOUT, T_("&About..."), T_("About the application") )
 
         self.menu_bar = wx.MenuBar()
         if wx.Platform != '__WXMAC__':
-            self.menu_bar.Append( self.menu_file, "&File" )
-        self.menu_bar.Append( self.menu_edit, "&Edit" )
-        self.menu_bar.Append( self.menu_view, "&View" )
-        self.menu_bar.Append( self.menu_actions, "&Actions" )
-        self.menu_bar.Append( self.menu_reports, "&Reports" )
-        self.menu_bar.Append( self.menu_bookmarks, "&Bookmarks" )
-        self.menu_bar.Append( self.menu_project, "&Project" )
-        self.menu_bar.Append( self.menu_help, "&Help" )
+            self.menu_bar.Append( self.menu_file, T_("&File") )
+        self.menu_bar.Append( self.menu_edit, T_("&Edit") )
+        self.menu_bar.Append( self.menu_view, T_("&View") )
+        self.menu_bar.Append( self.menu_actions, T_("&Actions") )
+        self.menu_bar.Append( self.menu_reports, T_("&Reports") )
+        self.menu_bar.Append( self.menu_bookmarks, T_("&Bookmarks") )
+        self.menu_bar.Append( self.menu_project, T_("&Project") )
+        self.menu_bar.Append( self.menu_help, T_("&Help") )
 
         self.SetMenuBar( self.menu_bar )
 
@@ -182,64 +189,73 @@ class WbFrame(wx.Frame):
         t.SetToolBitmapSize( bitmap_size )
         t.AddSimpleTool( wb_ids.id_SP_EditCut,
             wb_images.getBitmap( 'toolbar_images/editcut.png', bitmap_size ),
-            'Cut Files and Folders', 'Cut Files and Folders' )
+            T_('Cut Files and Folders'), T_('Cut Files and Folders') )
         t.AddSimpleTool( wb_ids.id_SP_EditCopy,
             wb_images.getBitmap( 'toolbar_images/editcopy.png', bitmap_size ),
-            'Copy Files and Folders', 'Copy Files and Folders' )
+            T_('Copy Files and Folders'), T_('Copy Files and Folders') )
         t.AddSimpleTool( wb_ids.id_SP_EditPaste,
             wb_images.getBitmap( 'toolbar_images/editpaste.png', bitmap_size ),
-            'Paste Files and Folders', 'Paste Files and Folders' )
+            T_('Paste Files and Folders'), T_('Paste Files and Folders') )
         t.AddSeparator()
         t.AddSimpleTool( wb_ids.id_Command_Shell,
             wb_images.getBitmap( 'toolbar_images/terminal.png', bitmap_size ),
-            'Command Shell', 'Start new command shell' )
+            T_('Command Shell'), T_('Start new command shell') )
         t.AddSimpleTool( wb_ids.id_File_Browser,
             wb_images.getBitmap( 'toolbar_images/file_browser.png', bitmap_size ),
-            'File Browser', 'File Browser' )
+            T_('File Browser'), T_('File Browser') )
         t.AddSeparator()
         t.AddSimpleTool( wb_ids.id_File_Edit,
             wb_images.getBitmap( 'toolbar_images/edit.png', bitmap_size ),
-            'Edit File', 'Edit File' )
+            T_('Edit File'), T_('Edit File') )
         t.AddSimpleTool( wb_ids.id_Shell_Open,
             wb_images.getBitmap( 'toolbar_images/open.png', bitmap_size ),
-            'Open File', 'Open File' )
+            T_('Open File'), T_('Open File') )
         t.AddSeparator()
         t.AddSimpleTool( wb_ids.id_SP_DiffWorkBase,
             wb_images.getBitmap( 'toolbar_images/diff.png', bitmap_size ),
-            'Diff changes against base', 'Diff changes against base' )
+            T_('Diff changes against base'), T_('Diff changes against base') )
         t.AddSimpleTool( wb_ids.id_SP_History,
             wb_images.getBitmap( 'toolbar_images/history.png', bitmap_size ),
-            'Show History log', 'Show History log' )
+            T_('Show History log'), T_('Show History log') )
         t.AddSimpleTool( wb_ids.id_SP_Info,
             wb_images.getBitmap( 'toolbar_images/info.png', bitmap_size ),
-            'File Information', 'File Information' )
+            T_('File Information'), T_('File Information') )
         t.AddSimpleTool( wb_ids.id_SP_Properties,
             wb_images.getBitmap( 'toolbar_images/property.png', bitmap_size ),
-            'File Properties', 'File Properties' )
+            T_('File Properties'), T_('File Properties') )
         t.AddSeparator()
         t.AddSimpleTool( wb_ids.id_SP_Add,
             wb_images.getBitmap( 'toolbar_images/add.png', bitmap_size ),
-            'Add Files and Folders', 'Add Files and Folders' )
+            T_('Add Files and Folders'), T_('Add Files and Folders') )
         t.AddSimpleTool( wb_ids.id_SP_Delete,
             wb_images.getBitmap( 'toolbar_images/delete.png', bitmap_size ),
-            'Delete selected Files and Folders', 'Delete selected Files and Folders' )
+            T_('Delete selected Files and Folders'), T_('Delete selected Files and Folders') )
         t.AddSimpleTool( wb_ids.id_SP_Revert,
             wb_images.getBitmap( 'toolbar_images/revert.png', bitmap_size ),
-            'Revert selected Files and Folders', 'Revert selected Files and Folders' )
+            T_('Revert selected Files and Folders'), T_('Revert selected Files and Folders') )
         t.AddSeparator()
         t.AddSimpleTool( wb_ids.id_SP_Lock,
             wb_images.getBitmap( 'toolbar_images/lock.png', bitmap_size ),
-            'Lock File', 'Lock File' )
+            T_('Lock File'), T_('Lock File') )
         t.AddSimpleTool( wb_ids.id_SP_Unlock,
             wb_images.getBitmap( 'toolbar_images/unlock.png', bitmap_size ),
-            'Unlock File', 'Unlock File' )
+            T_('Unlock File'), T_('Unlock File') )
         t.AddSeparator()
         t.AddSimpleTool( wb_ids.id_SP_Checkin,
             wb_images.getBitmap( 'toolbar_images/checkin.png', bitmap_size ),
-            'Checkin changes', 'Checkin changes' )
+            T_('Checkin changes'), T_('Checkin changes') )
         t.AddSimpleTool( wb_ids.id_SP_Update,
             wb_images.getBitmap( 'toolbar_images/update.png', bitmap_size ),
-            'Update working copy', 'Update working copy' )
+            T_('Update working copy'), T_('Update working copy') )
+        t.AddSeparator()
+        t.AddSimpleTool( wb_ids.id_View_Recursive,
+            wb_images.getBitmap( 'toolbar_images/flatview.png', bitmap_size ),
+            T_('Use recursive (flat) view'), T_('Use recursive (flat) view'),
+            isToggle=True )
+        t.AddSimpleTool( wb_ids.id_View_OnlyChanges,
+            wb_images.getBitmap( 'toolbar_images/onlychanges.png', bitmap_size ),
+            T_('Show only changed files'), T_('Show only changed files'),
+            isToggle=True )
 
         t.Realize()
 
@@ -247,15 +263,19 @@ class WbFrame(wx.Frame):
         s = self.CreateStatusBar()
         s.SetFieldsCount( WbFrame.status_num_fields )
         s.SetStatusWidths( WbFrame.status_widths )
-        s.SetStatusText("Work Bench", WbFrame.status_general)
+        s.SetStatusText(T_("Work Bench"), WbFrame.status_general)
         s.SetStatusText("", WbFrame.status_progress)
-        s.SetStatusText("Ready", WbFrame.status_action)
+        s.SetStatusText(T_("Ready"), WbFrame.status_action)
         if WbFrame.status_search != WbFrame.status_general:
             s.SetStatusText("", WbFrame.status_search)
 
         # Create the splitter windows
-        self.h_split = wx.SplitterWindow( self, -1 )
-        self.v_split = wx.SplitterWindow( self.h_split, -1 )
+        if 'wxMac' in wx.PlatformInfo:
+            style = wx.SP_LIVE_UPDATE | wx.SP_3DSASH
+        else:
+            style = wx.SP_LIVE_UPDATE
+        self.h_split = wx.SplitterWindow( self, -1, style=style )
+        self.v_split = wx.SplitterWindow( self.h_split, -1, style=style )
 
         # Make sure the splitters can't be removed by setting a minimum size
         self.v_split.SetMinimumPaneSize( 100 )
@@ -263,16 +283,21 @@ class WbFrame(wx.Frame):
 
         # Create the main panels
         self.log_panel = LogCtrlPanel( self.app, self.h_split )
+        self.log_panel.SetZoom( win_prefs.zoom )
         self.list_panel = wb_list_panel.WbListPanel( self.app, self, self.v_split )
         self.tree_panel = wb_tree_panel.WbTreePanel( self.app, self, self.v_split )
 
+        # Fixup the tab order that results from creating the tree and
+        # list panels in the wrong order
+        self.list_panel.MoveAfterInTabOrder( self.tree_panel )
+
         try_wrapper = wb_exceptions.TryWrapperFactory( self.app.log )
 
         size = self.GetClientSize()
 
         h_sash_pos = max( 200, int( size.height * win_prefs.h_sash_ratio) )
         v_sash_pos = max( 200, int( size.width  * win_prefs.v_sash_ratio) )
-
+        
         # Arrange the panels with the splitter windows
         self.v_split.SplitVertically( self.tree_panel, self.list_panel, v_sash_pos )
         self.h_split.SplitHorizontally( self.v_split, self.log_panel, h_sash_pos )
@@ -302,6 +327,9 @@ class WbFrame(wx.Frame):
             wx.EVT_MENU( event_source, wb_ids.id_View_Recursive, try_wrapper( self.OnToggleViewRecursive ) )
             wx.EVT_UPDATE_UI( event_source, wb_ids.id_View_Recursive, try_wrapper( self.OnUpdateViewRecursive ) )
 
+            wx.EVT_MENU( event_source, wb_ids.id_View_OnlyChanges, try_wrapper( self.OnToggleViewOnlyChanges ) )
+            wx.EVT_UPDATE_UI( event_source, wb_ids.id_View_OnlyChanges, try_wrapper( self.OnUpdateViewOnlyChanges ) )
+
             wx.EVT_MENU( event_source, wb_ids.id_SP_EditCopy, self.app.eventWrapper( self.OnSpEditCopy ) )
             wx.EVT_UPDATE_UI( event_source, wb_ids.id_SP_EditCopy, self.app.eventWrapper( self.OnUpdateUiSpEditCopy ) )
             wx.EVT_MENU( event_source, wb_ids.id_SP_EditCut, self.app.eventWrapper( self.OnSpEditCut ) )
@@ -407,6 +435,8 @@ class WbFrame(wx.Frame):
         wx.EVT_SPLITTER_SASH_POS_CHANGED( self.v_split, -1, self.OnVertSashPositionChanged )
         wx.EVT_SPLITTER_SASH_POS_CHANGED( self.h_split, -1, self.OnHorizSashPositionChanged )
 
+        wx.stc.EVT_STC_ZOOM(self, -1, self.OnZoom)
+        
         wx.EVT_CLOSE(self, try_wrapper( self.OnCloseWindow ))
 
         # default to the tree panel as the first set_focus can go missing
@@ -471,13 +501,13 @@ class WbFrame(wx.Frame):
 
     # Handler for the About menu command
     def OnCmdAbout(self, event):
-        str_message =    ('Work Bench version: %d.%d.%d-%d\n' %
+        str_message =    (T_('Work Bench version: %d.%d.%d-%d\n') %
                     (wb_version.major, wb_version.minor,
                      wb_version.patch, wb_version.build) +
                 '\n' + wb_source_control_providers.getProviderAboutStrings() +
-                '\nWxPython %d.%d.%d.%d %s' % wx.VERSION +
+                '\nwxPython %d.%d.%d.%d %s' % wx.VERSION +
                 '\nPython %d.%d.%d %s %d\n' % sys.version_info +
-                '\nCopyright Barry Scott (c) 2003-2007. All rights reserved'
+                T_('\nCopyright Barry Scott (c) 2003-2007. All rights reserved')
                 )
         wx.LogMessage( str_message )
 
@@ -491,12 +521,12 @@ class WbFrame(wx.Frame):
         self.refreshFrame()
 
     def OnUnlockedUi( self ):
-        self.setAction( 'Ready' )
+        self.setAction( T_('Ready') )
         self.tree_panel.updateTree()
 
     def OnSize( self, event ):
         if not self.IsMaximized():
-            self.app.prefs.getWindow().frame_size = event.GetSize()
+            self.app.prefs.getWindow().frame_size = self.GetSize()
         event.Skip()
 
     def OnMove( self, event ):
@@ -532,6 +562,10 @@ class WbFrame(wx.Frame):
         self.v_split.SetSashPosition( max( 200, int( w * win_prefs.v_sash_ratio ) ) )
         event.Skip()
 
+    def OnZoom(self, evt):
+        win_prefs = self.app.prefs.getWindow()
+        win_prefs.zoom = self.log_panel.GetZoom()
+        
     #------------------------------------------------------------------------
     def OnActivateApp( self, is_active ):
         if is_active and self.app.prefs.getView().auto_refresh:
@@ -583,6 +617,15 @@ class WbFrame(wx.Frame):
         view_prefs = self.app.prefs.getView()
         event.Check( view_prefs.view_recursive )
 
+    def OnToggleViewOnlyChanges( self, event ):
+        view_prefs = self.app.prefs.getView()
+        view_prefs.view_onlychanges = not view_prefs.view_onlychanges
+        self.refreshFrame()
+
+    def OnUpdateViewOnlyChanges( self, event ):
+        view_prefs = self.app.prefs.getView()
+        event.Check( view_prefs.view_onlychanges )
+
     def OnViewDiffWbDiff( self, event ):
         self.app.prefs.getDiffTool().diff_tool_mode = 'built-in'
         self.app.prefs.writePreferences()
@@ -698,7 +741,7 @@ class WbFrame(wx.Frame):
         bm_prefs = self.app.prefs.getBookmarks()
  
         if not bm_prefs.hasBookmark( pi.url ):
-            print 'Adding bookmark to %s' % pi.wc_path
+            print T_('Adding bookmark to %s') % pi.wc_path
             bm_prefs.addBookmark( pi )
 
             self.__addBookmarkMenuItem( pi )
@@ -1124,13 +1167,9 @@ class LogCtrlPanel(wx.Panel):
 
         wx.EVT_SIZE( self, wb_exceptions.TryWrapper( self.app.log, self.OnSize ) )
 
-        wx.EVT_MENU( self, wb_ids.id_NextControl, self.app.eventWrapper( self.OnNextControl ) )
 
     #---------- Event handlers ------------------------------------------------------------
 
-    def OnNextControl( self, event ):
-        print 'LogCtrlPanel.OnNextControl',event
-
     def OnSize( self, event ):
         self.text_ctrl.SetWindowSize( self.GetSize() )
 
@@ -1162,6 +1201,12 @@ class LogCtrlPanel(wx.Panel):
     def ClearLog( self ):
         self.text_ctrl.ClearText()
 
+    def GetZoom(self):
+        return self.text_ctrl.GetZoom()
+
+    def SetZoom(self, zoom):
+        self.text_ctrl.SetZoom(zoom)
+
 #--------------------------------------------------------------------------------
 class LogHandler(logging.Handler):
     def __init__( self, log_ctrl ):
@@ -1193,9 +1238,7 @@ class StyledLogCtrl(wx.stc.StyledTextCtrl):
     def __init__(self, app, parent):
         self.app = app
 
-        wx.stc.StyledTextCtrl.__init__(self, parent, -1,
-                wx.DefaultPosition, wx.DefaultSize, wx.NO_BORDER)
-
+        wx.stc.StyledTextCtrl.__init__(self, parent)
         self.SetReadOnly( True )
 
         self.style_normal = 0
@@ -1222,8 +1265,17 @@ class StyledLogCtrl(wx.stc.StyledTextCtrl):
         wx.EVT_KEY_DOWN( self, self.OnKeyDown )
 
     def OnKeyDown( self, event ):
+        """
+        Don't let the STC treat the TAB normally (insert a tab
+        character.)  Turn it into a navigation event instead.
+        """
         if event.GetKeyCode() == wx.WXK_TAB:
-            self.app.frame.tree_panel.SetFocus()
+            flags = wx.NavigationKeyEvent.IsForward
+            if event.ShiftDown():
+                flags = wx.NavigationKeyEvent.IsBackward
+            if event.ControlDown():
+                flags |= wx.NavigationKeyEvent.WinChange
+            self.Navigate(flags)            
         else:
             event.Skip()
 
