@@ -18,6 +18,7 @@ id_View_ControlledFiles = wx.NewId()
 id_View_IgnoredFiles = wx.NewId()
 id_View_UncontrolledFiles = wx.NewId()
 id_View_Recursive = wx.NewId()
+id_View_OnlyChanges = wx.NewId()
 id_ClearLog = wx.NewId()
 
 id_View_Diff_WbDiff = wx.NewId()
@@ -78,4 +79,3 @@ id_SP_Report_LocksWc = wx.NewId()
 id_SP_Report_LocksRepos = wx.NewId()
 id_SP_Report_BranchChanges = wx.NewId()
 
-id_NextControl = wx.NewId()
