@@ -67,9 +67,30 @@ class ListItemState:
 class WbListCtrl(wx.ListCtrl):
     def __init__( self, parent, list_id ):
         wx.ListCtrl.__init__( self, parent, list_id,
-                                style=wx.LC_REPORT|wx.NO_BORDER|wx.LC_HRULES|wx.LC_VIRTUAL )
+                                style=wx.LC_REPORT|wx.LC_HRULES|wx.LC_VIRTUAL )
         self.parent = parent
+        imSize = (16,16)
+        il = wx.ImageList(*imSize)
+        self.il_folder = il.Add( wx.ArtProvider.GetBitmap( wx.ART_FOLDER, size=imSize ) )
+        self.il_file = il.Add( wx.ArtProvider.GetBitmap( wx.ART_NORMAL_FILE, size=imSize ) )
+        self.AssignImageList( il, wx.IMAGE_LIST_SMALL )
 
+        self.doSelect = self.SelectFirstAtStart
+
+    def SelectFirstAtStart(self):
+        """
+        A simple hack to select the first item, but delay it until we
+        know we have items.  It's called from SetItemCount only the
+        first time it is called.
+        """
+        wx.CallAfter(self.Select, 0)
+        self.doSelect = None
+
+    def SetItemCount(self, count):
+        if self.doSelect and count > 0:
+            self.doSelect()
+        return wx.ListCtrl.SetItemCount(self, count)
+        
     def OnGetItemText(self, item, col):
         if self.parent.list_handler is not None:
             return self.parent.list_handler.OnGetItemText( item, col )
@@ -77,6 +98,13 @@ class WbListCtrl(wx.ListCtrl):
             return ''
 
     def OnGetItemImage(self, item):
+        if self.parent.list_handler is not None:
+            if self.parent.list_handler.isItemImageFolder( item ):
+                return self.il_folder
+
+            else:
+                return self.il_file
+
         return -1
 
     def OnGetItemAttr(self, item):
@@ -215,14 +243,21 @@ class WbListPanelCommon(wx.Panel):
         svn_data = wx.CustomDataObject(wx.CustomDataFormat("WorkBench.svn_wc_path"))
         svn_data.SetData( cPickle.dumps( all_filenames ) )
 
+        # Make a data object that other apps will recognize as a filename drag/drop
+        fn_data = wx.FileDataObject()
+        for name in all_filenames:
+            fn_data.AddFile(name)
 
-        # Now make a data object for the text and also a composite
-        # data object holding both of the others.
-        text_data = wx.TextDataObject( 'the text of the list ctrl file name' )
+# What is this for?  It just screws up the dragging of files to a text editor
+# that also accepts files...
+#        # Now make a data object for the text and also a composite
+#        # data object holding both of the others.
+#        text_data = wx.TextDataObject( 'the text of the list ctrl file name' )
 
         data = wx.DataObjectComposite()
         data.Add( svn_data )
-        data.Add( text_data )
+#        data.Add( text_data )
+        data.Add( fn_data )
 
         # And finally, create the drop source and begin the drag
         # and drop opperation
@@ -464,29 +499,29 @@ class HeaderPanel(wx.Panel):
 
         self.filter_changed_handler = None
 
+        # ToDo:  A wx.SearchCtrl would go great here instead of these widgets
         self.filter_field_choices = ['Name','Author']
         self.filter_choice_ctrl = wx.Choice( self, wx.NewId(), choices=self.filter_field_choices )
         self.filter_choice_ctrl.SetSelection( self.filter_field_choices.index( filter_field ) )
-        if wx.Platform == '__WXMAC__':
-            self.filter_text_ctrl = wx.TextCtrl( self, wx.NewId(), '', size=(-1,-1) )
-        else:
-            self.filter_text_ctrl = wx.TextCtrl( self, wx.NewId(), '', size=(-1,10) )
+        self.filter_text_ctrl = wx.TextCtrl( self )
         self.filter_clear_button = wx.Button( self, wx.NewId(), 'X', style=wx.BU_EXACTFIT, size=(30, -1) )
 
         # share the space 50/50
-        border = 3
-        self.h_sizer1.Add( self.url_text_ctrl, 50, wx.EXPAND|wx.ALL, border )
-        self.h_sizer1.Add( self.path_text_ctrl, 50, wx.EXPAND|wx.TOP|wx.BOTTOM|wx.RIGHT, border )
-
-        border = 1
-        self.h_sizer2.Add( self.filter_choice_ctrl, 0, wx.EXPAND|wx.LEFT|wx.RIGHT, border )
-        if wx.Platform == '__WXMAC__':
-            self.h_sizer2.Add( self.filter_text_ctrl, 1, wx.EXPAND|wx.ALL, border )
+        if 'wxMac' in wx.PlatformInfo:
+            filter_flags = wx.TOP|wx.BOTTOM|wx.RIGHT|wx.ALIGN_CENTER_VERTICAL
+            border = 5
+            left = wx.LEFT
         else:
-            self.h_sizer2.Add( self.filter_text_ctrl, 1, wx.EXPAND|wx.ALL, border+2 )
-        self.h_sizer2.Add( self.filter_clear_button, 0, wx.EXPAND|wx.LEFT|wx.RIGHT, border )
+            filter_flags = wx.BOTTOM|wx.RIGHT|wx.ALIGN_CENTER_VERTICAL
+            border = 3
+            left = 0
+        self.h_sizer1.Add( self.url_text_ctrl, 1,  left|wx.TOP|wx.BOTTOM|wx.RIGHT, border )
+        self.h_sizer1.Add( self.path_text_ctrl, 1, wx.TOP|wx.BOTTOM|wx.RIGHT, border )
+
+        self.h_sizer2.Add( self.filter_choice_ctrl, 0,  left|filter_flags, border )
+        self.h_sizer2.Add( self.filter_text_ctrl, 1,    filter_flags, border )
+        self.h_sizer2.Add( self.filter_clear_button, 0, filter_flags, border )
 
-        border = 3
         self.v_sizer.Add( self.h_sizer1, 0, wx.EXPAND|wx.ALL, 0 )
         self.v_sizer.Add( self.h_sizer2, 1, wx.EXPAND|wx.ALL, 0 )
 
@@ -494,20 +529,12 @@ class HeaderPanel(wx.Panel):
         wx.EVT_TEXT( self, self.filter_text_ctrl.GetId(), self.OnFilterTextChanged )
         wx.EVT_CHOICE( self, self.filter_choice_ctrl.GetId(), self.OnFilterTypeChanged )
 
-        wx.EVT_KEY_DOWN( self, self.OnKeyDown )
-
         self.SetAutoLayout( True )
         self.SetSizer( self.v_sizer )
         self.v_sizer.Fit( self )
         self.Layout()
 
 
-    def OnKeyDown( self, event ):
-        if event.GetKeyCode() == wx.WXK_TAB:
-            self.app.frame.list_panel.SetFocus()
-        else:
-            event.Skip()
-
     def setFocusFilter( self ):
         self.filter_text_ctrl.SetFocus()
 
