@@ -249,6 +249,9 @@ class PreferenceData:
     def getint( self, section_name, option_name ):
         return int( self.get( section_name, option_name ).strip() )
 
+    def getfloat( self, section_name, option_name ):
+        return float( self.get( section_name, option_name ).strip() )
+
     def getboolean( self, section_name, option_name ):
         return self.get( section_name, option_name ).strip().lower() == 'true'
 
@@ -467,15 +470,33 @@ class BookmarksPreferences(PreferenceSection):
 
         set_option = SetOption( pref_data, self.section_name )
 
-        for bookmark_name in self.all_bookmarks.keys():
-            pref_dict = {}
-            pref_dict[ 'bookmark_name' ] = bookmark_name
+        all_bookmarks = self.all_bookmarks.values()
+        all_bookmarks.sort( self.__cmpBookmarksByMenuAndName )
 
-            pi = self.all_bookmarks[ bookmark_name ]
-            pi.writePreferences( pref_dict )
+        for bookmark in all_bookmarks:
+            pref_dict = {}
+            pref_dict[ 'bookmark_name' ] = bookmark.wc_path
+
+            bookmark.writePreferences( pref_dict )
 
             pref_data.append_dict( self.section_name, 'bookmark', pref_dict )
 
+    def __cmpBookmarksByMenuAndName( self, a, b ):
+        if a.menu_folder != '':
+            a_key = a.menu_folder + '\001' + a.menu_name
+        else:
+            a_key = a.menu_name
+
+        if b.menu_folder != '':
+            b_key = b.menu_folder + '\001' + b.menu_name
+        else:
+            b_key = b.menu_name
+
+        rc = cmp( a_key, b_key )
+        if rc == 0:
+            rc = cmp( a.wc_path, b.wc_path )
+        return rc
+
     def addBookmark( self, pi, name=None ):
         if name is None:
             name = pi.wc_path
@@ -544,6 +565,7 @@ class WindowPreferences(PreferenceSection):
         self.frame_size = wx.Size( 700, 500 )
         self.frame_position = wx.DefaultPosition
         self.maximized = False
+        self.zoom = 0
 
     def readPreferences( self, pref_data ):
         get_option = GetOption( pref_data, self.section_name )
@@ -560,6 +582,12 @@ class WindowPreferences(PreferenceSection):
         self.frame_size = wx.Size( w, h )
 
         self.maximized = get_option.getbool( 'maximized' )
+        if get_option.has( 'zoom' ):
+            self.zoom = get_option.getint( 'zoom' )
+        if get_option.has( 'h_sash_ratio' ):
+            self.h_sash_ratio = get_option.getfloat( 'h_sash_ratio' )
+        if get_option.has( 'v_sash_ratio' ):
+            self.v_sash_ratio = get_option.getfloat( 'v_sash_ratio' )
 
     def writePreferences( self, pref_data ):
         set_option = SetOption( pref_data, self.section_name )
@@ -569,6 +597,9 @@ class WindowPreferences(PreferenceSection):
         set_option.set( 'width', self.frame_size.GetWidth() )
         set_option.set( 'height', self.frame_size.GetHeight() )
         set_option.set( 'maximized', self.maximized )
+        set_option.set( 'zoom', self.zoom )
+        set_option.set( 'h_sash_ratio', self.h_sash_ratio )
+        set_option.set( 'v_sash_ratio', self.v_sash_ratio )
 
 class DiffWindowPreferences(PreferenceSection):
     def __init__( self, app ):
@@ -578,6 +609,7 @@ class DiffWindowPreferences(PreferenceSection):
         self.frame_size = wx.Size( 700, 500 )
         self.frame_position = wx.DefaultPosition
         self.maximized = False
+        self.zoom = 0
 
     def readPreferences( self, pref_data ):
         get_option = GetOption( pref_data, self.section_name )
@@ -594,6 +626,8 @@ class DiffWindowPreferences(PreferenceSection):
         self.frame_size = wx.Size( w, h )
 
         self.maximized = get_option.getbool( 'maximized' )
+        if get_option.has( 'zoom' ):
+            self.zoom = get_option.getint( 'zoom' )
 
 
     def writePreferences( self, pref_data ):
@@ -604,6 +638,7 @@ class DiffWindowPreferences(PreferenceSection):
         set_option.set( 'width', self.frame_size.GetWidth() )
         set_option.set( 'height', self.frame_size.GetHeight() )
         set_option.set( 'maximized', self.maximized )
+        set_option.set( 'zoom', self.zoom )
 
 class ViewPreferences(PreferenceSection):
     def __init__( self, app ):
@@ -617,6 +652,7 @@ class ViewPreferences(PreferenceSection):
         self.view_controlled = True
         self.view_uncontrolled = True
         self.view_recursive = False
+        self.view_onlychanges = False
         self.column_order = ['Name','State','Date','Rev','Author','Type']
         self.column_widths = ['25','4','14','4','10','4']
 
@@ -631,9 +667,14 @@ class ViewPreferences(PreferenceSection):
             self.sort_field = get_option.getstr( 'sort_field' )
         if get_option.has( 'view_ignored' ):
             self.view_ignored = get_option.getbool( 'view_ignored' )
-        # always view controlled on startup
-        self.view_controlled = True
-        self.view_uncontrolled = True
+        if get_option.has( 'view_controlled' ):
+            self.view_controlled = get_option.getbool( 'view_controlled' )
+        if get_option.has( 'view_uncontrolled' ):
+            self.view_uncontrolled = get_option.getbool( 'view_uncontrolled' )
+        if get_option.has( 'view_recursive' ):
+            self.view_recursive = get_option.getbool( 'view_recursive' )
+        if get_option.has( 'view_onlychanges' ):
+            self.view_onlychanges = get_option.getbool( 'view_onlychanges' )
         if get_option.has( 'column_order' ):
             self.column_order = get_option.getstrlist( 'column_order', ',' )
         if get_option.has( 'column_widths' ):
@@ -641,6 +682,11 @@ class ViewPreferences(PreferenceSection):
         if self.sort_field not in self.column_order:
             self.sort_field = 'Name'
 
+        # always view controlled on startup
+        self.view_controlled = True
+        # avoid a blank list box on startup
+        self.view_onlychanges = False
+
     def writePreferences( self, pref_data ):
         set_option = SetOption( pref_data, self.section_name )
 
@@ -648,10 +694,14 @@ class ViewPreferences(PreferenceSection):
         set_option.set( 'sort_order', self.sort_order )
         set_option.set( 'sort_field', self.sort_field )
         set_option.set( 'view_ignored', self.view_ignored )
-        # don't need to save view_controlled or view_uncontrolled as we force it on at reload
+        set_option.set( 'view_controlled', self.view_controlled )
+        set_option.set( 'view_uncontrolled', self.view_uncontrolled )
+        set_option.set( 'view_recursive', self.view_recursive )
+        set_option.set( 'view_onlychanges', self.view_onlychanges )
         set_option.set( 'column_order', self.column_order, ',' )
         set_option.set( 'column_widths', self.column_widths, ',' )
 
+
 class EditorPreferences(PreferenceSection):
     def __init__( self, app ):
         PreferenceSection.__init__( self, 'Editor' )
