@@ -18,7 +18,7 @@ import wb_shell_commands
 
 class PreferencesDialog( wx.Dialog ):
     def __init__( self, parent, app ):
-        wx.Dialog.__init__( self, parent, -1, 'Preferences', size=(400,200) )
+        wx.Dialog.__init__( self, parent, -1, T_('Preferences'), size=(400,200) )
         self.app = app
         self.v_sizer = None
 
@@ -26,11 +26,10 @@ class PreferencesDialog( wx.Dialog ):
         try:
             self.initControls()
         except:
-            app.log.exception('PreferencesDialog')
-        self.SetAutoLayout( True )
+            app.log.exception(T_('PreferencesDialog'))
         self.SetSizer( self.v_sizer )
-        self.v_sizer.Fit( self )
         self.Layout()
+        self.Fit()
 
         self.CentreOnParent()
 
@@ -38,7 +37,7 @@ class PreferencesDialog( wx.Dialog ):
     def initControls( self ):
         self.v_sizer = wx.BoxSizer( wx.VERTICAL )
 
-        self.notebook = wx.Notebook( self, -1, size = (400, 200) )
+        self.notebook = wx.Notebook( self )
 
         self.v_sizer.Add( self.notebook, 0, wx.EXPAND|wx.ALL, 5 )
 
@@ -51,12 +50,9 @@ class PreferencesDialog( wx.Dialog ):
         # may want view page for editing the control file
         #self.pages.append( ViewPage( self.notebook, self.app ) )
 
-        self.notebook.SetAutoLayout( True )
-        self.notebook.Layout()
-
-        self.button_ok = wx.Button( self, wx.ID_OK, ' OK ' )
+        self.button_ok = wx.Button( self, wx.ID_OK, T_(' OK ') )
         self.button_ok.SetDefault()
-        self.button_cancel = wx.Button( self, wx.ID_CANCEL, ' Cancel ' )
+        self.button_cancel = wx.Button( self, wx.ID_CANCEL, T_(' Cancel ') )
 
         self.h_sizer = wx.BoxSizer( wx.HORIZONTAL )
         self.h_sizer.Add( (1, 1), 1, wx.EXPAND )
@@ -101,18 +97,18 @@ class PagePanel(wx.Panel):
 class EditorPage(PagePanel):
     def __init__( self, notebook, app ):
         self.app = app
-        PagePanel.__init__( self, notebook, 'Editor' )
+        PagePanel.__init__( self, notebook, T_('Editor') )
 
     def initControls( self ):
         p = self.app.prefs.getEditor()
 
-        self.static_text1 = wx.StaticText( self, -1, 'Editor: ', style=wx.ALIGN_RIGHT)
+        self.static_text1 = wx.StaticText( self, -1, T_('Editor: '), style=wx.ALIGN_RIGHT)
         self.text_ctrl_editor = wx.TextCtrl( self, -1, p.editor_image, wx.DefaultPosition, wx.Size(415, -1) )
 
-        self.static_text2 = wx.StaticText( self, -1, 'Edit Arguments: ', style=wx.ALIGN_RIGHT)
+        self.static_text2 = wx.StaticText( self, -1, T_('Edit Arguments: '), style=wx.ALIGN_RIGHT)
         self.text_ctrl_edit_arg = wx.TextCtrl( self, -1, p.editor_options, wx.DefaultPosition, wx.Size(315, -1) )
 
-        self.browse_button = wx.Button( self, -1, ' Browse... ')
+        self.browse_button = wx.Button( self, -1, T_(' Browse... '))
 
         self.grid_sizer = wx.FlexGridSizer( 0, 3, 0, 0 )
         self.grid_sizer.AddGrowableCol( 1 )
@@ -138,16 +134,16 @@ class EditorPage(PagePanel):
 
     def OnBrowseExe( self, event ):
         if wx.Platform == '__WXMSW__':
-            file_type = 'Executable files (*.exe)|*.exe'
+            file_type = T_('Executable files (*.exe)|*.exe')
         elif wx.Platform == '__WXMAC__':
-            file_type = 'Applications|*.app|Executable files|*'
+            file_type = T_('Applications|*.app|Executable files|*')
         else:
-            file_type = 'Executable files|*'
+            file_type = T_('Executable files|*')
 
         filename = self.text_ctrl_editor.GetValue()
         file_dialog = wx.FileDialog( 
             self,
-            'Choose an Executable file',
+            T_('Choose an Executable file'),
             os.path.dirname( filename ),
             os.path.basename( filename ),
             file_type,
@@ -177,8 +173,8 @@ class EditorPage(PagePanel):
 
         if not valid:
             wx.MessageBox(
-                'You must enter a valid editor executable',
-                'Warning',
+                T_('You must enter a valid editor executable'),
+                T_('Warning'),
                 wx.OK | wx.ICON_EXCLAMATION,
                 self )
             return False
@@ -188,7 +184,7 @@ class EditorPage(PagePanel):
 class DiffToolPage(PagePanel):
     def __init__( self, notebook, app ):
         self.app = app
-        PagePanel.__init__( self, notebook, 'Diff Tool' )
+        PagePanel.__init__( self, notebook, T_('Diff Tool') )
 
     def initControls( self ):
         p = self.app.prefs.getDiffTool()
@@ -196,7 +192,7 @@ class DiffToolPage(PagePanel):
         self.mode_values = ['built-in', 'external-gui-diff', 'external-shell-diff', 'svn-diff']
         self.diff_tools = {'built-in': '', 'external-gui-diff': p.gui_diff_tool, 'external-shell-diff': p.shell_diff_tool, 'svn-diff': ''}
         self.options = {'built-in': '', 'external-gui-diff': p.gui_diff_tool_options, 'external-shell-diff': p.shell_diff_tool_options, 'svn-diff': ''}
-        self.mode_choice_values = ['Work Bench Diff', 'External GUI Diff Command', 'External Text Diff', 'svn diff']
+        self.mode_choice_values = [T_('Work Bench Diff'), T_('External GUI Diff Command'), T_('External Text Diff'), T_('SVN diff')]
         self.mode_choice = wx.Choice( self, -1, choices = self.mode_choice_values )
         if p.diff_tool_mode not in self.mode_values:
             p.diff_tool_mode = 'built-in'
@@ -205,25 +201,25 @@ class DiffToolPage(PagePanel):
         self.text_ctrl_diff_tool = wx.TextCtrl( self, -1, self.diff_tools[self.mode], wx.DefaultPosition, wx.Size(415, -1) )
         self.text_ctrl_options = wx.TextCtrl( self, -1, self.options[self.mode], wx.DefaultPosition, wx.Size(315, -1) )
 
-        self.browse_button = wx.Button( self, -1, ' Browse... ')
+        self.browse_button = wx.Button( self, -1, T_(' Browse... ') )
 
         self.grid_sizer = wx.FlexGridSizer( 0, 3, 0, 0 )
         self.grid_sizer.AddGrowableCol( 1 )
 
-        self.grid_sizer.Add( wx.StaticText( self, -1, 'Mode: ', style=wx.ALIGN_RIGHT), 1, wx.EXPAND|wx.ALL, 3 )
+        self.grid_sizer.Add( wx.StaticText( self, -1, T_('Mode: '), style=wx.ALIGN_RIGHT), 1, wx.EXPAND|wx.ALL, 3 )
         self.grid_sizer.Add( self.mode_choice, 0, wx.ALIGN_LEFT, 5 )
         self.grid_sizer.Add( (1, 1), 0, wx.EXPAND )
         
-        self.grid_sizer.Add( wx.StaticText( self, -1, 'Diff Tool: ', style=wx.ALIGN_RIGHT), 1, wx.EXPAND|wx.ALL, 3 )
+        self.grid_sizer.Add( wx.StaticText( self, -1, T_('Diff Tool: '), style=wx.ALIGN_RIGHT), 1, wx.EXPAND|wx.ALL, 3 )
         self.grid_sizer.Add( self.text_ctrl_diff_tool, 0, wx.EXPAND|wx.ALL, 5 )
         self.grid_sizer.Add( self.browse_button, 0, wx.EXPAND )
 
-        self.grid_sizer.Add( wx.StaticText( self, -1, 'Tool Arguments: ', style=wx.ALIGN_RIGHT), 1, wx.EXPAND|wx.ALL, 3 )
+        self.grid_sizer.Add( wx.StaticText( self, -1, T_('Tool Arguments: '), style=wx.ALIGN_RIGHT), 1, wx.EXPAND|wx.ALL, 3 )
         self.grid_sizer.Add( self.text_ctrl_options, 0, wx.EXPAND|wx.ALL, 5 )
         self.grid_sizer.Add( (1, 1), 0, wx.EXPAND )
 
-        self.grid_sizer.Add( wx.StaticText( self, -1, 'Use', style=wx.ALIGN_RIGHT), 1, wx.EXPAND|wx.ALL, 3 )
-        self.grid_sizer.Add( wx.StaticText( self, -1, '%nl for left file name, %nr for right file name,\n%tl for left title, %tr for right title',
+        self.grid_sizer.Add( wx.StaticText( self, -1, T_('Use'), style=wx.ALIGN_RIGHT), 1, wx.EXPAND|wx.ALL, 3 )
+        self.grid_sizer.Add( wx.StaticText( self, -1, T_('%nl for left file name, %nr for right file name,\n%tl for left title, %tr for right title'),
                                            style=wx.ALIGN_LEFT), 1, wx.EXPAND|wx.ALL, 3 )
         self.grid_sizer.Add( (1, 1), 0, wx.EXPAND )
         
@@ -261,16 +257,16 @@ class DiffToolPage(PagePanel):
 
     def OnBrowseExe( self, event ):
         if wx.Platform == '__WXMSW__':
-            file_type = 'Executable files (*.exe)|*.exe'
+            file_type = T_('Executable files (*.exe)|*.exe')
         elif wx.Platform == '__WXMAC__':
-            file_type = 'Applications|*.app|Executable files|*'
+            file_type = T_('Applications|*.app|Executable files|*')
         else:
-            file_type = 'Executable files|*'
+            file_type = T_('Executable files|*')
 
         filename = self.text_ctrl_diff_tool.GetValue()
         file_dialog = wx.FileDialog(
             self,
-            'Choose an Executable file',
+            T_('Choose an Executable file'),
             os.path.dirname( filename ),
             os.path.basename( filename ),
             file_type,
@@ -287,12 +283,12 @@ class DiffToolPage(PagePanel):
 class ShellPage(PagePanel):
     def __init__( self, notebook, app ):
         self.app = app
-        PagePanel.__init__( self, notebook, 'Shell' )
+        PagePanel.__init__( self, notebook, T_('Shell') )
 
     def initControls( self ):
         p = self.app.prefs.getShell()
 
-        self.static_text1 = wx.StaticText( self, -1, 'Terminal Init Command: ', style=wx.ALIGN_RIGHT)
+        self.static_text1 = wx.StaticText( self, -1, T_('Terminal Init Command: '), style=wx.ALIGN_RIGHT)
         self.text_ctrl_shell_init_command = wx.TextCtrl( self, -1, p.shell_init_command, wx.DefaultPosition, wx.Size(300, -1) )
 
         self.grid_sizer = wx.FlexGridSizer( 0, 2, 0, 0 )
@@ -300,7 +296,7 @@ class ShellPage(PagePanel):
 
         terminal_program_list = wb_shell_commands.getTerminalProgramList()
         if len(terminal_program_list) > 0:
-            self.static_text2 = wx.StaticText( self, -1, 'Terminal Program: ', style=wx.ALIGN_RIGHT)
+            self.static_text2 = wx.StaticText( self, -1, T_('Terminal Program: '), style=wx.ALIGN_RIGHT)
             self.terminal_program_list_ctrl = wx.Choice( self, -1, choices=terminal_program_list, size=(150,-1) )
             if p.shell_terminal in terminal_program_list:
                 self.terminal_program_list_ctrl.SetStringSelection( p.shell_terminal )
@@ -317,7 +313,7 @@ class ShellPage(PagePanel):
         file_browser_program_list = wb_shell_commands.getFileBrowserProgramList()
 
         if len(file_browser_program_list) > 0:
-            self.static_text3 = wx.StaticText( self, -1, 'File Brower Program: ', style=wx.ALIGN_RIGHT)
+            self.static_text3 = wx.StaticText( self, -1, T_('File Browser Program: '), style=wx.ALIGN_RIGHT)
             self.file_browser_program_list_ctrl = wx.Choice( self, -1, choices=file_browser_program_list, size=(150,-1) )
             if p.shell_file_browser in file_browser_program_list:
                 self.file_browser_program_list_ctrl.SetStringSelection( p.shell_file_browser )
@@ -352,7 +348,7 @@ class ViewPage(PagePanel):
 
     def __init__( self, notebook, app ):
         self.app = app
-        PagePanel.__init__( self, notebook, 'View' )
+        PagePanel.__init__( self, notebook, T_('View') )
         self.selected_item = None
 
     def initControls( self ):
@@ -360,15 +356,15 @@ class ViewPage(PagePanel):
 
         self.filename_list = wx.ListCtrl( self, ViewPage.id_filename_list, wx.DefaultPosition,
                 wx.Size( -1, 100 ), wx.LC_REPORT )
-        self.filename_list.InsertColumn( 0, 'Exclude filename' )
+        self.filename_list.InsertColumn( 0, T_('Exclude filename') )
         self.filename_list.SetColumnWidth( 0, 400 )
 
         for index, filename in enumerate( p.excluded_filenames_list ):
             self.filename_list.InsertStringItem( index, filename )
 
-        self.button_add = wx.Button( self, ViewPage.id_add, ' Add ' )
+        self.button_add = wx.Button( self, ViewPage.id_add, T_(' Add ') )
         self.button_add.Enable( False )
-        self.button_del = wx.Button( self, ViewPage.id_del, ' Delete ' )
+        self.button_del = wx.Button( self, ViewPage.id_del, T_(' Delete ') )
         self.button_del.Enable( False )
         self.pattern_text_ctrl = wx.TextCtrl( self, ViewPage.id_pattern_text, '',
                 wx.DefaultPosition, wx.Size(200, -1), style=wx.TE_PROCESS_ENTER )
@@ -478,7 +474,7 @@ class ListColumnsPage(PagePanel):
         self.app = app
         self.selected_name = None
         self.column_info = wb_subversion_list_handler_common.ViewColumnInfo()
-        PagePanel.__init__( self, notebook, 'Columns' )
+        PagePanel.__init__( self, notebook, T_('Columns') )
 
     def initControls( self ):
         p = self.app.prefs.getView()
@@ -486,16 +482,16 @@ class ListColumnsPage(PagePanel):
 
         self.excluded_list = wx.ListCtrl( self, ListColumnsPage.id_excluded_list, wx.DefaultPosition,
                 wx.Size( 200, 100 ), wx.LC_REPORT )
-        self.excluded_list.InsertColumn( 0, 'Column' )
+        self.excluded_list.InsertColumn( 0, T_('Column') )
         self.excluded_list.SetColumnWidth( 0, 100 )
-        self.excluded_list.InsertColumn( 1, 'Width', wx.LIST_FORMAT_RIGHT )
+        self.excluded_list.InsertColumn( 1, T_('Width'), wx.LIST_FORMAT_RIGHT )
         self.excluded_list.SetColumnWidth( 1, 80 )
 
         self.included_list = wx.ListCtrl( self, ListColumnsPage.id_included_list, wx.DefaultPosition,
                 wx.Size( 200, 100 ), wx.LC_REPORT )
-        self.included_list.InsertColumn( 0, 'Column' )
+        self.included_list.InsertColumn( 0, T_('Column') )
         self.included_list.SetColumnWidth( 0, 100 )
-        self.included_list.InsertColumn( 1, 'Width', wx.LIST_FORMAT_RIGHT )
+        self.included_list.InsertColumn( 1, T_('Width'), wx.LIST_FORMAT_RIGHT )
         self.included_list.SetColumnWidth( 1, 80 )
 
         for name in self.column_info.getColumnOrder():
@@ -513,14 +509,14 @@ class ListColumnsPage(PagePanel):
             self.excluded_list.SetStringItem( index, 1, str(info.width) )
 
 
-        self.button_include = wx.Button( self, ListColumnsPage.id_include, ' Include --> ' )
+        self.button_include = wx.Button( self, ListColumnsPage.id_include, T_(' Include --> ') )
         self.button_include.Enable( False )
-        self.button_exclude = wx.Button( self, ListColumnsPage.id_exclude, ' <-- Exclude ' )
+        self.button_exclude = wx.Button( self, ListColumnsPage.id_exclude, T_(' <-- Exclude ') )
         self.button_exclude.Enable( False )
 
-        self.button_up = wx.Button( self, ListColumnsPage.id_move_up, ' Move Up ' )
+        self.button_up = wx.Button( self, ListColumnsPage.id_move_up, T_(' Move Up ') )
         self.button_up.Enable( False )
-        self.button_down = wx.Button( self, ListColumnsPage.id_move_down, ' Move Down ' )
+        self.button_down = wx.Button( self, ListColumnsPage.id_move_down, T_(' Move Down ') )
         self.button_down.Enable( False )
 
         self.width_text_ctrl = wx.TextCtrl( self, ListColumnsPage.id_width, '',
@@ -565,9 +561,9 @@ class ListColumnsPage(PagePanel):
         try:
             width = int(self.width_text_ctrl.GetValue())
         except ValueError:
-            wx.MessageBox( 'Width for %s must be an number between %d and %d' %
+            wx.MessageBox( T_('Width for %s must be an number between %d and %d') %
                         (info.name, info.min_width, info.max_width),
-                'Warning',
+                T_('Warning'),
                 wx.OK | wx.ICON_EXCLAMATION,
                 self )
             return
@@ -576,9 +572,9 @@ class ListColumnsPage(PagePanel):
         and width <= info.max_width ):
             info.width = width
         else:
-            wx.MessageBox( 'Width for %s must be between %d and %d' %
+            wx.MessageBox( T_('Width for %s must be between %d and %d') %
                         (info.name, info.min_width, info.max_width),
-                'Warning',
+                T_('Warning'),
                 wx.OK | wx.ICON_EXCLAMATION,
                 self )
             return
@@ -623,9 +619,9 @@ class ListColumnsPage(PagePanel):
         try:
             width = int(self.width_text_ctrl.GetValue())
         except ValueError:
-            wx.MessageBox( 'Width for %s must be an number between %d and %d' %
+            wx.MessageBox( T_('Width for %s must be an number between %d and %d') %
                         (info.name, info.min_width, info.max_width),
-                'Warning',
+                T_('Warning'),
                 wx.OK | wx.ICON_EXCLAMATION,
                 self )
             return
@@ -636,9 +632,9 @@ class ListColumnsPage(PagePanel):
             index = self.included_list.FindItem( -1, info.name )
             self.included_list.SetStringItem( index, 1, str(width) )
         else:
-            wx.MessageBox( 'Width for %s must be between %d and %d' %
+            wx.MessageBox( T_('Width for %s must be between %d and %d') %
                         (info.name, info.min_width, info.max_width),
-                'Warning',
+                T_('Warning'),
                 wx.OK | wx.ICON_EXCLAMATION,
                 self )
         
@@ -688,8 +684,8 @@ class ListColumnsPage(PagePanel):
 
     def validate( self ):
         if self.included_list.FindItem( -1, 'Name' ) < 0:
-            wx.MessageBox( 'You must include the Name column',
-                'Warning',
+            wx.MessageBox( T_('You must include the Name column'),
+                T_('Warning'),
                 wx.OK | wx.ICON_EXCLAMATION,
                 self )
             return False
@@ -699,25 +695,25 @@ class ListColumnsPage(PagePanel):
 class LogHistoryPage(PagePanel):
     def __init__( self, notebook, app ):
         self.app = app
-        PagePanel.__init__( self, notebook, 'Log History' )
+        PagePanel.__init__( self, notebook, T_('Log History') )
 
     def initControls( self ):
         p = self.app.prefs.getLogHistory()
 
         self.mode_values = ['show_all', 'show_limit', 'show_since' ]
-        self.mode_choice_values = ['Show all entries', 'Show only', 'Show since']
-        self.mode_label = wx.StaticText( self, -1, 'Default mode: ', style=wx.ALIGN_RIGHT)
+        self.mode_choice_values = [T_('Show all entries'), T_('Show only'), T_('Show since')]
+        self.mode_label = wx.StaticText( self, -1, T_('Default mode: '), style=wx.ALIGN_RIGHT)
         self.mode_ctrl = wx.Choice( self, -1, choices = self.mode_choice_values )
         self.mode_ctrl.SetSelection( self.mode_values.index( p.default_mode ) )
 
-        self.limit_label = wx.StaticText( self, -1, 'Default limit: ', style=wx.ALIGN_RIGHT)
+        self.limit_label = wx.StaticText( self, -1, T_('Default limit: '), style=wx.ALIGN_RIGHT)
         self.limit_ctrl = wx.TextCtrl( self, -1, str( p.default_limit ), wx.DefaultPosition, wx.Size(415, -1) )
 
-        self.since_label = wx.StaticText( self, -1, 'Default since interval (days): ', style=wx.ALIGN_RIGHT)
+        self.since_label = wx.StaticText( self, -1, T_('Default since interval (days): '), style=wx.ALIGN_RIGHT)
         self.since_ctrl = wx.TextCtrl( self, -1, str( p.default_since_days_interval ), wx.DefaultPosition, wx.Size(415, -1) )
 
-        self.tags_label = wx.StaticText( self, -1, 'Default Include tags: ', style=wx.ALIGN_RIGHT)
-        self.tags_ctrl = wx.CheckBox( self, -1, 'Include tags in log history' )
+        self.tags_label = wx.StaticText( self, -1, T_('Default Include tags: '), style=wx.ALIGN_RIGHT)
+        self.tags_ctrl = wx.CheckBox( self, -1, T_('Include tags in log history') )
         self.tags_ctrl.SetValue( p.default_include_tags )
 
         self.grid_sizer = wx.FlexGridSizer( 0, 2, 0, 0 )
@@ -754,8 +750,8 @@ class LogHistoryPage(PagePanel):
                 raise ValueError( 'out of range' )
         except ValueError:
             wx.MessageBox(
-                'Limit must be greater then 0',
-                'Warning',
+                T_('Limit must be greater then 0'),
+                T_('Warning'),
                 wx.OK | wx.ICON_EXCLAMATION,
                 self )
             return False
@@ -766,8 +762,8 @@ class LogHistoryPage(PagePanel):
                 raise ValueError( 'out of range' )
         except ValueError:
             wx.MessageBox(
-                'Since days must be greater then 0',
-                'Warning',
+                T_('Since days must be greater then 0'),
+                T_('Warning'),
                 wx.OK | wx.ICON_EXCLAMATION,
                 self )
             return False
