@@ -26,7 +26,6 @@ wc_path_text_ctrl_id = wx.NewId()
 name_text_ctrl_id = wx.NewId()
 url_trunk_path_text_ctrl_id = wx.NewId()
 url_tags_path_text_ctrl_id = wx.NewId()
-url_tags_path_enable_ctrl_id = wx.NewId()
 
 wizard_id = wx.NewId()
 
@@ -70,7 +69,9 @@ class ProjectDialog(wx.Dialog):
 
         self.url_tags_label = wx.StaticText( self, -1, 'Subversion Tags URL:', style=wx.ALIGN_RIGHT )
         self.url_tags_ctrl = wx.TextCtrl( self, url_tags_path_text_ctrl_id, '' )
-        self.url_tags_enable_ctrl = wx.CheckBox( self, url_tags_path_enable_ctrl_id, 'Enable' )
+
+        self.url_branches_label = wx.StaticText( self, -1, 'Subversion Branches URL:', style=wx.ALIGN_RIGHT )
+        self.url_branches_ctrl = wx.TextCtrl( self, url_tags_path_text_ctrl_id, '' )
 
         self.g_sizer.Add( self.url_trunk_label, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 5 )
         self.g_sizer.Add( self.url_trunk_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
@@ -78,7 +79,11 @@ class ProjectDialog(wx.Dialog):
 
         self.g_sizer.Add( self.url_tags_label, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 5 )
         self.g_sizer.Add( self.url_tags_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
-        self.g_sizer.Add( self.url_tags_enable_ctrl, 0, wx.EXPAND )
+        self.g_sizer.Add( (1, 1), 0, wx.EXPAND )
+
+        self.g_sizer.Add( self.url_branches_label, 1, wx.EXPAND|wx.NORTH|wx.ALIGN_RIGHT, 5 )
+        self.g_sizer.Add( self.url_branches_ctrl, 0, wx.EXPAND|wx.ALL, 5 )
+        self.g_sizer.Add( (1, 1), 0, wx.EXPAND )
 
         self.newfile_dir_label = wx.StaticText( self, -1, "New File Template Folder: ", style=wx.ALIGN_RIGHT)
         self.newfile_dir_ctrl = wx.TextCtrl( self, -1, '' )
@@ -114,7 +119,6 @@ class ProjectDialog(wx.Dialog):
         wx.EVT_TEXT( self, wc_path_text_ctrl_id, self.updateControls )
         wx.EVT_TEXT( self, url_trunk_path_text_ctrl_id, self.updateControls )
         wx.EVT_TEXT( self, url_tags_path_text_ctrl_id, self.updateControls )
-        wx.EVT_CHECKBOX( self, url_tags_path_enable_ctrl_id, self.updateControls )
         wx.EVT_BUTTON( self, self.newfile_dir_browse.GetId(), self.OnBrowseNewFileTemplateDir )
 
         self._update_controls_lock = False
@@ -126,8 +130,7 @@ class ProjectDialog(wx.Dialog):
         self._update_controls_lock = True
 
         # If the wc_path exists and is a svn wc then disable the url field
-        wc_path = self.wc_path_ctrl.GetValue()
-        wc_path = os.path.expanduser( wc_path )
+        wc_path = os.path.expanduser( self.wc_path_ctrl.GetValue().strip() )
 
         url = None
         if os.path.exists( wc_path ):
@@ -145,13 +148,21 @@ class ProjectDialog(wx.Dialog):
                 self.name_ctrl.SetValue( os.path.basename( wc_path ) )
             self.url_trunk_ctrl.SetValue( url )
 
-        if( self.url_tags_enable_ctrl.IsChecked()
-        and url is not None
+        if( url is not None
         and self.url_tags_ctrl.GetValue().strip() == '' ):
             url_parts = url.split('/')
             if 'trunk' in url_parts:
-                url_parts[ url_parts.index('trunk') ] = 'tags'
-                self.url_tags_ctrl.SetValue( '/'.join( url_parts ) )
+                trunk_index = url_parts.index('trunk')
+                url_parts[ trunk_index ] = 'tags'
+                self.url_tags_ctrl.SetValue( '/'.join( url_parts[:trunk_index+1] ) )
+
+        if( url is not None
+        and self.url_branches_ctrl.GetValue().strip() == '' ):
+            url_parts = url.split('/')
+            if 'trunk' in url_parts:
+                trunk_index = url_parts.index('trunk')
+                url_parts[ trunk_index ] = 'branches'
+                self.url_branches_ctrl.SetValue( '/'.join( url_parts[:trunk_index+1] ) )
 
         self._update_controls_lock = False
 
@@ -185,6 +196,12 @@ class ProjectDialog(wx.Dialog):
                 style=wx.OK|wx.ICON_ERROR );
             return
 
+        url = self.url_branches_ctrl.GetValue().strip()
+        if url and not is_url( url ):
+            wx.MessageBox( '%s is not a valid Subversion tags URL' % url,
+                style=wx.OK|wx.ICON_ERROR );
+            return
+
         if self.wc_path_ctrl.GetValue().strip() == '':
             wx.MessageBox( 'Enter a Working copy path', style=wx.OK|wx.ICON_ERROR );
             return
@@ -236,7 +253,8 @@ class ProjectDialog(wx.Dialog):
         pi.init( self.name_ctrl.GetValue().strip(),
             wc_path=os.path.expanduser( self.wc_path_ctrl.GetValue().strip() ),
             url=self.url_trunk_ctrl.GetValue().strip(),
-            tags_url=self.url_tags_ctrl.GetValue().strip() )
+            tags_url=self.url_tags_ctrl.GetValue().strip(),
+            branches_url=self.url_branches_ctrl.GetValue().strip() )
 
         return pi
 
@@ -252,7 +270,6 @@ class UpdateProjectDialog(ProjectDialog):
         self.url_trunk_ctrl.SetValue( self.project_info.url )
         self.wc_path_ctrl.SetValue( self.project_info.wc_path )
         self.url_tags_ctrl.SetValue( self.project_info.tags_url )
-        self.url_tags_enable_ctrl.SetValue( self.project_info.tags_url != '' )
         self.newfile_dir_ctrl.SetValue( self.project_info.new_file_template_dir )
 
         self.updateControls()
@@ -432,13 +449,12 @@ class WorkingCopyExistsPage(TitledPage):
 
         self._update_controls_lock = False
 
-
     def loadState( self, state ):
         self.wc_path_ctrl.SetValue( state.wc_path )
         self.updateControls()
 
     def saveState( self, state ):
-        state.wc_path = self.wc_path_ctrl.GetValue().strip()
+        state.wc_path = os.path.expanduser( self.wc_path_ctrl.GetValue().strip() )
         state.url_path = self.url_ctrl.GetLabel().strip()
 
         if not os.path.exists( state.wc_path ):
@@ -689,11 +705,18 @@ class ProjectNamePage(TitledPage):
     def saveState( self, state ):
         state.project_name = self.name_ctrl.GetValue().strip()
 
+        if state.project_name == '':
+            wx.MessageBox( 'Project name is blank.\n'
+                    'Enter a project name',
+                    style=wx.OK|wx.ICON_ERROR );
+            return False
+
         if state.project_name in self.parent.pi_names:
             wx.MessageBox( 'Project %s already exist.\n'
                     'Choose another name' % state.project_name,
-                style=wx.OK|wx.ICON_ERROR );
-            return
+                    style=wx.OK|wx.ICON_ERROR );
+            return False
+
         return True
 
     def GetNext( self ):
