@@ -42,5 +42,8 @@ class ShowDiffFrame(wx.Frame):
         text_control.InsertText( 0, text )
         text_control.SetReadOnly( True )
 
+        # Todo: should update the zoom value if the user changes it in this window...
+        text_control.SetZoom(diff_prefs.zoom)
+        
         self.CreateStatusBar()
         self.Show( True )
