@@ -72,10 +72,11 @@ class ProjectInfo:
         if get_option.has( 'menu_name' ):
             self.menu_name = get_option.getstr( 'menu_name' )
 
-    def writePreferences( self, set_option ):
-        set_option.set( 'provider', self.provider_name )
-        set_option.set( 'name', self.project_name )
-        set_option.set( 'new_file_template_dir', self.new_file_template_dir )
+    def writePreferences( self, pref_dict ):
+        pref_dict[ 'provider' ] = self.provider_name
+        pref_dict[ 'name' ] = self.project_name
+        if self.new_file_template_dir not in [None,'']:
+            pref_dict[ 'new_file_template_dir' ] = self.new_file_template_dir
         if self.menu_name is not None:
-            set_option.set( 'menu_name', self.menu_name )
-        set_option.set( 'menu_folder', self.menu_folder )
+            pref_dict[ 'menu_name' ] = self.menu_name
+        pref_dict[ 'menu_folder' ] = self.menu_folder
