@@ -363,32 +363,12 @@ class CheckinListPanel(wb_list_panel_common.WbListPanelCommon):
         wb_list_panel_common.WbListPanelCommon.__init__( self, app, frame, parent )
 
     def getAcceleratorTableInit( self ):
-        if wx.Platform == '__WXMAC__':
-            acc_init =[
-                (wx.ACCEL_ALT, ord('D'), wb_ids.id_SP_DiffWorkBase),
-                (wx.ACCEL_ALT, ord('E'), wb_ids.id_File_Edit),
-                (wx.ACCEL_ALT, ord('L'), wb_ids.id_SP_History),
-                (wx.ACCEL_ALT, ord('I'), wb_ids.id_SP_Info),
-                (wx.ACCEL_ALT, ord('P'), wb_ids.id_SP_Properties),
-                (wx.ACCEL_ALT, ord('O'), wb_ids.id_Shell_Open),
+        acc_init =[
+                (wx.ACCEL_CMD, ord('D'), wb_ids.id_SP_DiffWorkBase),
+                (wx.ACCEL_CMD, ord('E'), wb_ids.id_File_Edit),
+                (wx.ACCEL_CMD, ord('L'), wb_ids.id_SP_History),
+                (wx.ACCEL_CMD, ord('I'), wb_ids.id_SP_Info),
+                (wx.ACCEL_CMD, ord('P'), wb_ids.id_SP_Properties),
+                (wx.ACCEL_CMD, ord('O'), wb_ids.id_Shell_Open),
                 ]
-        elif wx.Platform == '__WXMSW__':
-            acc_init =[
-                (wx.ACCEL_CTRL, ord('D'), wb_ids.id_SP_DiffWorkBase),
-                (wx.ACCEL_CTRL, ord('E'), wb_ids.id_File_Edit),
-                (wx.ACCEL_CTRL, ord('L'), wb_ids.id_SP_History),
-                (wx.ACCEL_CTRL, ord('I'), wb_ids.id_SP_Info),
-                (wx.ACCEL_CTRL, ord('P'), wb_ids.id_SP_Properties),
-                (wx.ACCEL_CTRL, ord('O'), wb_ids.id_Shell_Open),
-                ]
-        else:
-            # Unix
-            acc_init =[
-                (wx.ACCEL_CTRL, ord('D'), wb_ids.id_SP_DiffWorkBase),
-                (wx.ACCEL_CTRL, ord('E'), wb_ids.id_File_Edit),
-                (wx.ACCEL_CTRL, ord('L'), wb_ids.id_SP_History),
-                (wx.ACCEL_CTRL, ord('I'), wb_ids.id_SP_Info),
-                (wx.ACCEL_CTRL, ord('P'), wb_ids.id_SP_Properties),
-                ]
-
         return acc_init
