@@ -147,7 +147,7 @@ def getHistoryEntries( project_info, filename, limit, revision_end, include_tags
                         break
 
         except pysvn.ClientError, e:
-            self.log.info( 'Cannot find tags in %s - %s' % (tags_url, str(e)) )
+            print 'Cannot find tags in %s - %s' % (tags_url, str(e))
 
     all_history_entries.sort( __cmpLogEntryHighToLow )
     return info.URL, all_history_entries
@@ -383,19 +383,11 @@ class PanelFilter(wx.Panel):
         wx.EVT_TEXT( self, self.filter_text_ctrl.GetId(), self.OnFilterTextChanged )
         wx.EVT_CHOICE( self, self.filter_choice_ctrl.GetId(), self.OnFilterTypeChanged )
 
-        wx.EVT_KEY_DOWN( self, self.OnKeyDown )
-
         self.SetAutoLayout( True )
         self.SetSizer( self.v_sizer )
         self.v_sizer.Fit( self )
         self.Layout()
 
-    def OnKeyDown( self, event ):
-        if event.GetKeyCode() == wx.WXK_TAB:
-            self.app.frame.list_panel.SetFocus()
-        else:
-            event.Skip()
-
     def setFocusFilter( self ):
         self.filter_text_ctrl.SetFocus()
 
@@ -457,7 +449,6 @@ class LogHistoryPanel:
         # run from recent to old
         self.all_log_entries.sort( self.by_rev )
 
-
         self.filter_field = 'Comment'
         self.filter_text = ''
         self.all_filtered_log_entries = all_log_entries
@@ -490,6 +481,7 @@ class LogHistoryPanel:
         self.panel_filter.setFilterChangedHandler( self.OnFilterChanged )
 
         self.list_ctrl = WbHistoryListCtrl( self.panel_history, self, id_list )
+        self.list_ctrl.SetFocus()
         self.all_item_attr = {}
 
         self.list_ctrl.InsertColumn( self.col_revision, "Revision" )
@@ -700,6 +692,7 @@ class LogHistoryPanel:
         self.list_ctrl.SetItemCount( len(self.all_filtered_log_entries) )
         if len(self.all_filtered_log_entries) > 0:
             self.list_ctrl.RefreshItems( 0, len(self.all_filtered_log_entries)-1 )
+            self.list_ctrl.SetItemState( 0, wx.LIST_STATE_SELECTED, wx.LIST_STATE_SELECTED )
 
     #---------- Command handlers ----------------------------------------------------------
     def OnViewCommand( self, event ):
