@@ -1,6 +1,6 @@
 '''
  ====================================================================
- Copyright (c) 2003-2006 Barry A Scott.  All rights reserved.
+ Copyright (c) 2003-2007 Barry A Scott.  All rights reserved.
 
  This software is licensed as described in the file LICENSE.txt,
  which you should have received as part of this distribution.
@@ -23,7 +23,8 @@ class InfoDialog(wx.Dialog):
         self.g_sizer_list = []
 
         self.addGroup( 'Entry' )
-        self.addRow( 'Path:',path )
+        value_ctrl = self.addRow( 'Path:',path )
+        value_ctrl.SetFocus()
 
         #print 'info_entry_or_info2_list',info_entry_or_info2_list
         if type(info_entry_or_info2_list) == types.ListType:
@@ -160,7 +161,7 @@ class InfoDialog(wx.Dialog):
             self.addRow( 'Checksum:', wc_info['checksum'] )
 
     def addGroup( self, label ):
-        self.g_sizer = wx.FlexGridSizer( 0, 2, 0, 0 )
+        self.g_sizer = wx.FlexGridSizer( 0, 2, 5, 5 )
         self.g_sizer.AddGrowableCol( 1 )
 
         self.border = wx.StaticBox( self, -1, label )
@@ -179,6 +180,8 @@ class InfoDialog(wx.Dialog):
                                         style=wx.TE_MULTILINE )
         else:
             value_ctrl = wx.TextCtrl( self, -1, unicode(value) )
+        value_ctrl.SetSelection( -1, -1 )
 
-        self.g_sizer.Add( label_ctrl, 1, wx.EXPAND|wx.ALL|wx.ALIGN_RIGHT, 3 )
-        self.g_sizer.Add( value_ctrl, 0, wx.EXPAND, 5 )
+        self.g_sizer.Add( label_ctrl, 1, wx.LEFT|wx.ALIGN_RIGHT|wx.ALIGN_CENTER_VERTICAL, 3 )
+        self.g_sizer.Add( value_ctrl, 0, wx.EXPAND|wx.RIGHT, 3)
+        return value_ctrl
