@@ -226,7 +226,7 @@ class SubversionListHandler(wb_subversion_list_handler_common.SubversionListHand
         self.app.refreshFrame()
 
     def Cmd_File_Delete( self, all_rows ):
-        if not self.app.confirmAction( 'Delete', self.getStatusAndFilenames( all_rows ) ):
+        if not self.app.confirmAction( 'Delete File', self.getStatusAndFilenames( all_rows ) ):
             return
 
         for filename, is_controlled, text_status, prop_status in [
@@ -295,7 +295,7 @@ class SubversionListHandler(wb_subversion_list_handler_common.SubversionListHand
         and prop_status in [pysvn.wc_status_kind.normal, pysvn.wc_status_kind.none] ):
             self.project_info.client_fg.copy( old_filename, new_full_filename )
         else:
-            raise EnvironmentError( 'Cannot move an added or modified file' )
+            raise EnvironmentError( 'Cannot copy an added or modified file' )
 
     def __moveFile( self, old_filename, new_full_filename, is_controlled, text_status, prop_status ):
         if not is_controlled:
