@@ -147,7 +147,10 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
         return self.is_project_parent
 
     def updateStatus( self ):
-        self.project_info.updateStatus()
+        try:
+            self.project_info.updateStatus()
+        except pysvn.ClientError, e:
+            print 'Error: %s' % e.args[0]
 
     def getBranchOriginRevision( self ):
         if self.__branch_origin_revision is None:
@@ -244,6 +247,21 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
         else:
             self.all_files = self.project_info.getFilesStatus()
 
+        view_prefs = self.app.prefs.getView()
+        if view_prefs.view_onlychanges:
+            modified_states = [ pysvn.wc_status_kind.modified,
+                                pysvn.wc_status_kind.added,
+                                pysvn.wc_status_kind.deleted,
+                                pysvn.wc_status_kind.conflicted,
+                                ]
+            af = self.all_files
+            self.all_files = []
+            for f in af:
+                text_status = self.getTextStatus(f)
+                prop_status = self.getPropStatus(f)
+                if text_status in modified_states or prop_status in modified_states:
+                    self.all_files.append( f )
+                    
         self.all_files.sort( SortList( sort_data, self.project_info ) )
 
         self.__restoreListSelectionState( selection_state )
@@ -311,7 +329,9 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
         return self.column_info.getColumnOrder()[col]
 
     def OnGetItemText( self, index, col ):
-        prefix_len = len( self.project_info.wc_path ) + 1
+        prefix_len = len( self.project_info.wc_path )
+        if not self.project_info.wc_path.endswith( os.sep ):
+            prefix_len += 1
 
         column = self.column_info.getNameByColumn( col )
 
@@ -365,6 +385,24 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
 
         return self.all_item_attr[ colour ]
 
+    def isItemImageFolder(self, item):
+        if self.project_info.need_checkout:
+            return True
+
+        elif self.GetItemIsDir( item ):
+            return True
+
+        else:
+            return False
+
+    def GetItemIsDir(self, item):
+        status = self.all_files[ item ]
+        if status.entry is None:
+            is_dir = os.path.isdir( status.path )
+        else:
+            is_dir = status.entry.kind == pysvn.node_kind.dir
+        return is_dir
+    
     def __get_NameColumn( self, status, prefix_len ):
         if status.entry is None:
             is_dir = os.path.isdir( status.path )
@@ -475,7 +513,8 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
             text_status = self.getTextStatus( row )
             if text_status in [pysvn.wc_status_kind.unversioned]:
                 state.versioned = False
-            else:
+
+            if text_status not in [pysvn.wc_status_kind.unversioned, pysvn.wc_status_kind.ignored]:
                 state.unversioned = False
 
             state.new_versioned = state.new_versioned and text_status in [pysvn.wc_status_kind.added]
@@ -488,10 +527,12 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
                                 pysvn.wc_status_kind.conflicted])
             state.need_checkin = state.need_checkin and (text_status in [pysvn.wc_status_kind.added,
                                     pysvn.wc_status_kind.deleted,
+                                    pysvn.wc_status_kind.replaced,
                                     pysvn.wc_status_kind.modified]
                             or
                             prop_status in [pysvn.wc_status_kind.added,
                                     pysvn.wc_status_kind.deleted,
+                                    pysvn.wc_status_kind.replaced,
                                     pysvn.wc_status_kind.modified])
             state.conflict = state.conflict and text_status in [pysvn.wc_status_kind.conflicted]
 
