@@ -257,7 +257,9 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
             # is it the  'is not a working copy' error?
             if e.args[1][0][1] == 155007:
                 return
-            raise e
+
+            print 'Error: %s' % e.args[0]
+            return
 
         if entry is None:
             self.url = ''
