@@ -251,22 +251,8 @@ class ReportLockListPanel(wb_list_panel_common.WbListPanelCommon):
         pass
 
     def getAcceleratorTableInit( self ):
-        if wx.Platform == '__WXMAC__':
-            acc_init =[
-                (wx.ACCEL_ALT, ord('D'), wb_ids.id_SP_DiffWorkHead),
-                (wx.ACCEL_ALT, ord('L'), wb_ids.id_SP_History),
+        acc_init =[
+                (wx.ACCEL_CMD, ord('D'), wb_ids.id_SP_DiffWorkHead),
+                (wx.ACCEL_CMD, ord('L'), wb_ids.id_SP_History),
                 ]
-        elif wx.Platform == '__WXMSW__':
-            acc_init =[
-                (wx.ACCEL_CTRL, ord('D'), wb_ids.id_SP_DiffWorkHead),
-                (wx.ACCEL_CTRL, ord('L'), wb_ids.id_SP_History),
-                ]
-        else:
-            # Unix
-            acc_init =[
-                (wx.ACCEL_CTRL, ord('D'), wb_ids.id_SP_DiffWorkBase),
-                (wx.ACCEL_CTRL, ord('L'), wb_ids.id_SP_History),
-                ]
-
-
         return acc_init
