@@ -75,7 +75,7 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
             or (file.entry is not None and file.entry.kind == pysvn.node_kind.dir) ):
                 pi = wb_subversion_project_info.ProjectInfo( self.app, self.project_info )
                 name = os.path.basename( file.path )
-                if file.entry is None:
+                if file.entry is None or file.entry.url is None:
                     # fake up the url - maybe a failed checkout/update
                     url = '%s/%s' % (self.project_info.url, name )
                 else:
@@ -344,9 +344,10 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
         return output_lines
 
     def Cmd_Dir_Delete( self ):
-        if self.app.confirmAction( 'Delete', [('', self.project_info.wc_path)] ):
+        confirmed, force = self.app.confirmForceAction( 'Delete Folder', [('', self.project_info.wc_path)] )
+        if confirmed:
             try:
-                self.project_info.client_fg.remove( self.project_info.wc_path )
+                self.project_info.client_fg.remove( self.project_info.wc_path, force=force )
             except pysvn.ClientError, e:
                 self.app.log_client_error( e )
             self.app.refreshFrame()
