@@ -51,7 +51,7 @@ pysvn.wc_status_kind.modified:      True,
 pysvn.wc_status_kind.none:          False,
 pysvn.wc_status_kind.normal:        False,
 pysvn.wc_status_kind.obstructed:    False,
-pysvn.wc_status_kind.replaced:      False,
+pysvn.wc_status_kind.replaced:      True,
 pysvn.wc_status_kind.unversioned:   False,
 }
 
