@@ -45,6 +45,7 @@ class TreeState:
         for item in self.__dict__.items():
             print 'TreeState: %s -> %r' % item
 
+
 #--------------------------------------------------------------------------------
 #
 #
@@ -74,54 +75,19 @@ class WbTreePanel(wx.Panel):
 
             self.tree_ctrl.Bind( wx.EVT_PAINT, self.OnPaint )
 
-        if wx.Platform == '__WXMAC__':
-            acc_init = [
-                (wx.ACCEL_ALT, ord('C'), wb_ids.id_SP_EditCopy),
-                (wx.ACCEL_ALT, ord('X'), wb_ids.id_SP_EditCut),
-                (wx.ACCEL_ALT, ord('V'), wb_ids.id_SP_EditPaste),
+        acc_init = [
+                (wx.ACCEL_CMD, ord('C'), wb_ids.id_SP_EditCopy),
+                (wx.ACCEL_CMD, ord('X'), wb_ids.id_SP_EditCut),
+                (wx.ACCEL_CMD, ord('V'), wb_ids.id_SP_EditPaste),
 
-                (wx.ACCEL_ALT, ord('A'), wb_ids.id_SP_Add),
-                (wx.ACCEL_ALT, ord('L'), wb_ids.id_SP_History),
-                (wx.ACCEL_ALT, ord('I'), wb_ids.id_SP_Info),
-                (wx.ACCEL_ALT, ord('P'), wb_ids.id_SP_Properties),
-                (wx.ACCEL_ALT, ord('R'), wb_ids.id_SP_Revert),
-                (wx.ACCEL_ALT, ord('U'), wb_ids.id_SP_Update),
+                (wx.ACCEL_CMD, ord('A'), wb_ids.id_SP_Add),
+                (wx.ACCEL_CMD, ord('L'), wb_ids.id_SP_History),
+                (wx.ACCEL_CMD, ord('I'), wb_ids.id_SP_Info),
+                (wx.ACCEL_CMD, ord('P'), wb_ids.id_SP_Properties),
+                (wx.ACCEL_CMD, ord('R'), wb_ids.id_SP_Revert),
+                (wx.ACCEL_CMD, ord('U'), wb_ids.id_SP_Update),
                 (wx.ACCEL_NORMAL, wx.WXK_DELETE, wb_ids.id_SP_Delete),
-                (wx.ACCEL_ALT, ord('O'), wb_ids.id_Shell_Open),
-                (wx.ACCEL_NORMAL, wx.WXK_TAB, wb_ids.id_NextControl),
-                ]
-        elif wx.Platform == '__WXMSW__':
-            acc_init = [
-                (wx.ACCEL_CTRL, ord('C'), wb_ids.id_SP_EditCopy),
-                (wx.ACCEL_CTRL, ord('X'), wb_ids.id_SP_EditCut),
-                (wx.ACCEL_CTRL, ord('V'), wb_ids.id_SP_EditPaste),
-
-                (wx.ACCEL_CTRL, ord('A'), wb_ids.id_SP_Add),
-                (wx.ACCEL_CTRL, ord('L'), wb_ids.id_SP_History),
-                (wx.ACCEL_CTRL, ord('I'), wb_ids.id_SP_Info),
-                (wx.ACCEL_CTRL, ord('P'), wb_ids.id_SP_Properties),
-                (wx.ACCEL_CTRL, ord('R'), wb_ids.id_SP_Revert),
-                (wx.ACCEL_CTRL, ord('U'), wb_ids.id_SP_Update),
-                (wx.ACCEL_NORMAL, wx.WXK_DELETE, wb_ids.id_SP_Delete),
-                (wx.ACCEL_CTRL, ord('O'), wb_ids.id_Shell_Open),
-                (wx.ACCEL_NORMAL, wx.WXK_TAB, wb_ids.id_NextControl),
-                ]
-        else:
-            # Unix
-            acc_init = [
-                (wx.ACCEL_CTRL, ord('C'), wb_ids.id_SP_EditCopy),
-                (wx.ACCEL_CTRL, ord('X'), wb_ids.id_SP_EditCut),
-                (wx.ACCEL_CTRL, ord('V'), wb_ids.id_SP_EditPaste),
-
-                (wx.ACCEL_CTRL, ord('A'), wb_ids.id_SP_Add),
-                (wx.ACCEL_CTRL, ord('L'), wb_ids.id_SP_History),
-                (wx.ACCEL_CTRL, ord('I'), wb_ids.id_SP_Info),
-                (wx.ACCEL_CTRL, ord('P'), wb_ids.id_SP_Properties),
-                (wx.ACCEL_CTRL, ord('R'), wb_ids.id_SP_Revert),
-                (wx.ACCEL_CTRL, ord('U'), wb_ids.id_SP_Update),
-                (wx.ACCEL_NORMAL, wx.WXK_DELETE, wb_ids.id_SP_Delete),
-                (wx.ACCEL_CTRL, ord('O'), wb_ids.id_Shell_Open),
-                (wx.ACCEL_NORMAL, wx.WXK_TAB, wb_ids.id_NextControl),
+                (wx.ACCEL_CMD, ord('O'), wb_ids.id_Shell_Open),
                 ]
 
         acc_tab = wx.AcceleratorTable( acc_init )
@@ -148,8 +114,6 @@ class WbTreePanel(wx.Panel):
         wx.EVT_SET_FOCUS( self.tree_ctrl, self.OnSetFocus )
         wx.EVT_KILL_FOCUS( self.tree_ctrl, self.OnKillFocus )
 
-        wx.EVT_MENU( self, wb_ids.id_NextControl, self.app.eventWrapper( self.OnNextControl ) )
-
         # start up by skipping ui updates until we have the tree control initialised
         self.__skip_update_ui = True
 
@@ -232,9 +196,6 @@ class WbTreePanel(wx.Panel):
         #print 'WbTreePanel.OnDragEnd'
         pass
 
-    def OnNextControl( self, event ):
-        self.frame.list_panel.setFocusFilter()
-
     def getSelectionProjectHandler( self ):
         item = self.tree_ctrl.GetSelection()
         if not item:
@@ -436,6 +397,9 @@ class WbTreePanel(wx.Panel):
         if not tree_pi:
             return
 
+        p = self.app.prefs.getView()
+        if p.view_recursive:
+            busy = wx.BusyInfo("Refreshing view...", self.frame)
         tree_pi.updateStatus()
         self.updateTreeItem( item )
 
@@ -498,6 +462,10 @@ class WbTreePanel(wx.Panel):
         if pi == self.list_panel.getProjectInfo():
             return;
 
+        p = self.app.prefs.getView()
+        if p.view_recursive:
+            busy = wx.BusyInfo("Refreshing view...", self.frame)
+
         if pi is None:
             self.list_panel.clearHandler()
         else:
@@ -569,6 +537,8 @@ class WbTreePanel(wx.Panel):
         # move the selection to the clicked on node
         point = event.GetPosition();
         item, flags = self.tree_ctrl.HitTest( point )
+        if (flags&wx.TREE_HITTEST_NOWHERE) != 0:
+            return
         self.tree_ctrl.SelectItem( item )
         self.changedSelection( self.tree_ctrl.GetPyData( item ) )
 
@@ -914,9 +884,9 @@ class WbTreeCtrl(wx.TreeCtrl):
         self.id_tree = wx.NewId()
 
         if wx.Platform == '__WXMSW__':
-            style = wx.TR_HAS_BUTTONS|wx.NO_BORDER
+            style = wx.TR_HAS_BUTTONS
         else:
-            style = wx.TR_HAS_BUTTONS|wx.NO_BORDER|wx.TR_HIDE_ROOT
+            style = wx.TR_HAS_BUTTONS|wx.TR_HIDE_ROOT
  
         wx.TreeCtrl.__init__( self, parent, self.id_tree, 
                                 wx.DefaultPosition,
@@ -967,7 +937,7 @@ class WbTreeCtrl(wx.TreeCtrl):
 
         if a_handler.isProjectParent():
             # compare nodes in the root - projects
-            cmp( self.GetItemText( a_item ).lower(), self.GetItemText( b_item ).lower() )
+            return cmp( self.GetItemText( a_item ).lower(), self.GetItemText( b_item ).lower() )
         else:
             # compare children of projects
             return cmp( a_pi.wc_path.lower(), b_pi.wc_path.lower() )
